%[NBa,NBf,NUMMAC,NUMMON,NUMNEU,DAMAGE,MCP1T,MACLIFE,PneumoT,IL8T,T,INF] = AlveolusExtended(indice,pars,pars2,seed,interPlot)
%
%Input variables:
%pars:   1.Number of bacteria.
%        2.Number of macrophages.
%        3.Chemokine diffusion constant.
%        4.Antigens per bacteria.
%        5.Movement in sessile phase.
%        6.Movement in flowing phase.
%        7.Radial flow.
%        8.Bacteria dobling time.
%        9.Probability interchanged.
%       10.Macrophage movement.
%       11.Phagocytosys rate.
%       12.Maximum bacteria per macrophage.
%       13.Distance to sense the metabolic gradient.
%       14.Time when bacteria have half of the capsule built.
%       15.Kinetic constant of monocyte recruitment.
%       16.Threthold to recruit monocytes.
%       17.Maximal monocyte recruitment rate.
%       18.Kinetic constant of neutrophils recruitment.
%       19.Threthold to recruit neutrophils.
%       20.Maximal neutrophils recruitment.
%       21.Neutrophils half-life in hours.
%       22.Weitgh of damage on the recruitment of neutrophils.
%       23.Threshold of the effect of the capsule on change of phase, between 0 and 1.
%       24.Probability of bacteria to die because of complement and antibiotics, between 0 and 1.
%       25.Barrier damage constant by neutrophils,
%       26.Barrier restoration constant by neutrophils. 
%pars2: 1.kirak1syn
%       2.kyrak1deg
%       3.kirak1ph
%       4.kirak1ph2
%       5.kirak1pdeg
%       6.kikksyn
%       7.kikkdeg
%       8.kikkact
%       9.kikkadeg
%       10.knfkbgain
%       11.knfkbloss
%       12.kmikbatransc
%       13.kmikbadeg
%       14.kikbatransl
%       15.kikbaloss
%       16.kmil8transc1
%       17.kmil8transc2
%       18.kmil8deg
%       19.kil8transl
%       20.kil8deg
%       21.K1
%       22.K2
%       23.K3
%       24.Ntot
%indice: index for the figures names.
%seed: seed control for random number generators.
%interPlot: iteration number control. 
%
%Output variables:
%NB: number of bacteria of simulation.
%NUMMAC: number of macrophages of simulation.
%T: time of simulation.
%NBa: number of bacteria adhered to the epithelium of simulation.
%NBf: number of bacteria floating in the lining liquid of simulation.
%NUMMON: number of monocytes of simulation.
%NUMNEU: number of neutrophils of simulation.
%DAMAGE: variable accounting of the alveolus epithelium damage.
%MCP1T: MCP1 chemokine concentration in the alveolus.
%MACLIFE: probability of macrophages to keep alive.
%PneumoT: pneumolysin concentration in the alveolus.
%IL8T: IL-8 concentraion in the alveolus.
%INF: Variable accounting to the simulation output.
%
%Multilevel model of the bacterial (Streptococcus pneumoniae) infection of
%an alveolus. It is simulated the stablishment of the infection. Bacteria
%interact with the alveolar macrophages and lung epithelial cells.
%
%Epithelial cells have intracellular signaling structure for inflammation
%through NFkB signaling pathway using ordinary differential equations
%(modeleqs).
%
%Bacteria and macrophages interact in the surfice of epithelial cells,
%modelled as an agent basd model (bacsMulti).
%
%modeleqs:
%Mathematical model using ordinary differential equations addapted from
%publication [ref] of legionella infection.
%TRL is activated by bacteria or IL1B from macrophages and triggers the
%kinase cascade through NFkB signaling pathway to produce MCP-1 chemokine
%to atract macrophages. The model is calibrated with MCP-1 [[PMID: 16834785]].
%
%bacsMulti:
%Mathematical simulation of bacterial groth and movement in a single
%alveolus together with macrophages movement and bacteria clearance.
%
%-Bacteria growth with a saturable process.
%-Bacteria jump stochasticaly between two liquid phases in alveolus: flowing
%phasde and stationary phase.
%-Coughing can be simulated, inactivated by default.
%-Bacteria move in a random walk way, faster in the flowing phase.
%-Macrophages move in a randomn walk way following the chemokine gradient 
%produced by epithelial cells.
%-Macrophages eat bacteria. First attach and then there is a dynamics of
%phagogytosis. Macrophages die if the number of attached bacteria is very
%high.
%-There is a defined flow velocity of the mobile liquid phase.
%-Bacteria leave the alveolus when reach the border.
%
%Version 1.2 (17.02.2017) by Guido Santos
%-Output variables contain all history.
%-New output variable considering the time.
%
%Version 1.3 (08.09.2017) by Guido Santos
%-The simulation does not stop before the final time defined.
%-The saturation does not play a role in the bacterial growth.
%-The infection group is defined for a final number of bacteria higher than 10
%-The no infection group is defined for a final number of bacteria equal to 0.
%-The final time changed to 10 hours
%
%Version 1.3.1 Asynchronous bacterial growth
%
%Version 1.4 (20.02.2018) Generalized spatial model
%-Adding variables that diffuse now is simpler.
%
%Version 1.5 (01.03.2018)
%-Included the monocyte recruitment.
%
%Version 1.5.1 (02.03.2018)
%-The parameters are included in a structure (Pstru) to facilitate the
%manipulation.
%
%Version 1.6 (19.03.2018)
%-The alveolus is round.
%
%Version 1.6.1 (25.06.2018)
%-Macrophages only follow signals from bacteria. MCP-1 only recruit cells
% from the blood stream
%
%Version 1.6.2 (31.07.2018)
%-Pneumolysin is produced by bacteria and kills macrophages
%
%Version 1.6.3 (21.08.2018)
%-Monocytes are included in the round version. They are recruited and behave as macrophages
%-Cellular movement and phagocytosis are enconded as functions
%-Macrophages and monocytes contains the intracellular signalling pathway
%-Death neutrophils can be tracked
%-The variable Pstru.infMon indicates which monocytes have eaten a
%neutrophil
%
%Version 1.6.4 (09.10.2018)
%-Monocytes and neutrophils natural decay is continuous instead of discrete
%
%Version 1.6.5 (19.10.2018)
%-Following floating bacteria and attached bacteria independently.
%
%Version 1.7.1 (11/06/2019)
%Model calibrated with data.
%
%Version 1.7.2 (16/08/2019)
%Antibiotics were added.
%Bacteria resist antibiotics with a probability that can be einherited with small variations

%% Main function
function [NBa,NBf,NUMMAC,NUMMON,NUMNEU,DAMAGE,MCP1T,CXCL5T,MACLIFE,PneumoT,IL8T,T,INF,OUTBAC] = AlveolusExtended(indice,pars,pars2,seed,interPlot)
%Define seed
if (exist('seed','var') == 0 || numel(seed) == 0)
    seed = 'shuffle'; %Shuffle the seed if it doesnt exist
end
rng(seed)
%% Initial configuration
% close all %Close previous figures
if (exist('pars','var') == 0 || numel(pars) == 0)
    pars = ones(27,1); %Define the input if it doesnt exist
end
if (exist('pars2','var') == 0 || numel(pars2) == 0)
    pars2 = ones(24,1); %Define the input if it doesnt exist
end
if (exist('interPlot','var') == 0 || numel(interPlot) == 0)
    interPlot = 1; %Define the input if it doesnt exist
end
%% Display parameters
Pstru.tmax  = 1e6; %Maximal time to run a single solution in seconds
movie       = 0; %If 1 show results and save movie
pantalla    = 1; %If 1 show the results in command windows
plotTime    = 0; %If 1 plots the dynamics of the variables
Pstru.Itime = clock; %Initial time
%% Simulation parameters
INF       = [];
nummon    = 0; %Initial number of monocytes
numneu    = 0; %Initial number of neutrophils
Bcrit     = 10; %Number of bacteria above which it will include the solution in the high infection group
incre     = 10; %Interval of time between synchronization of models in minutes
FT        = 24; %Final time for the model in hours
solver    = @ode45; %Integration method
numEQS    = 14; %Number of equations for variables
numEQS2   = 9; %Number of equations for variables for phagocytes
IndexSpat = [9,10,11,12,15];%Introduce the indexes of the variables that diffuse
maxbac    = 1e4; %Maximum number of bacteria in the alveolus simulated, not relevant
onoff     = 0; %Turn off the signal from MCP-1 to the alveolar macrophages
ff        = 11; %Figure index
iteplot   = 10; %Number of iteration per plot
Ndelay    = 10; %Number of equations for the delay of the neutrophil damage
%% Biological parameters
%From literature
 %Alveolum
alvEnt = [11,22,27,34,35,7,8,15,30,32,40,3,29,24,21,23,20,12,5,10]; %Indexes of the alveolus entry. Estimated from [[PMID: 27695315]]
exit   = 0.5536; %Angle that define the border of the alveolus entry. Estimated from [[PMID: 27695315]]
AlvRad = 100; %Alveolar radious [[PMID: 14512270]]
Cel    = 54.6533; %Microm of epithelial cell (54.6533 is the size of the edge of the icosaedron)(30 microM [[PMID: 25360787 & PMID: 7611375]]) 
liquid = 1; %Lining liquid width in microm from Figure 6A [[PMID: 17290033]]
DamDif = 2e4; %Equivalent size of the damage diffusion trhough the tissue (fit)
FN     = 1; %Factor to change the units of MCP-1 to ng/ml. (normalized to 1600 pg/ml MCP-1 for 7 bacteria per alveolus [[DOI: 10.4049/jimmunol.0804096]])
PMs    = [ones(1,8),8700,53000,2505,DamDif,1,9900]; %Molecular weights of the chemokines. MCP calculated from  [[PMID: 26808501]] and [[https://doi.org/10.1002/bit.260220504]]
dif    = 38640./((PMs).^(1/3)); %Give specific values of diffusion constant to different variables, expression taken from [[https://doi.org/10.1002/bit.260220504]]
step3  = 4.2e-2; %min-1. Radial flow (4.2e-2) Fitted to alveolar clearance in figura 3B [[PMID: 17290033]] calculated in Excel parameters calculation.xlsx (sheet: alveoli flow) 
 %Baceria
numbac      = round(11*pars(1)); %Initial number of bacteria (11 by default) [[normalized to 1 macrophage to fit to mice data]]
fuera       = 0; %Bacteria leaving the alveolus
growth      = 200; %Min. 199.2 min doubling time. Iterations per division (5e2),(3.32 hours from [[pag 38 book: ISBN 978-1-908230-17-1]])
bacsize     = 0.5; %Bacterium minimal size (microm). [[https://microbewiki.kenyon.edu/index.php/Streptococcus_pneumoniae]]
capsize     = 0.75; %Increase in bacterial size by capsule (microm).  [[https://microbewiki.kenyon.edu/index.php/Streptococcus_pneumoniae]]
pneumo1     = 2.3e1; %Pneumolysin production rate before 15 hours [[PMID: 2097494]]
pneumo2     = 3.6e-1; %Pneumolysin production rate after 15 hours [[PMID: 2097494]]
pneumotime1 = 15; %Threshold defined by data [[PMID: 2097494]]
pneumotime2 = 5; %Time of transition from pneumolysin rates
 %Antibiotics
antibi             = 1; %Antibiotics concentration
antibiK            = 0; %Antibiotics decay constant
probAB             = 0.0035; % Probability of surviving in presence of antibiotics for 24 hours [[8726030]].    
probAB             = ones(numbac,1)*probAB;
probAB(probAB < 0) = 0; %Prevents negative numbers
probAB(probAB > 1) = 1; %Prevents probabilities higher than 1
maxprobAB          = 1; %Maximal probability of survival in presence of antibiotics
antibHour          = pars(27); %Time the antibiotics are introduced
divBac             = 0; %Divergence respecting the original bacteria after dividing
 %Macrophages
nummac = 1; %Number of macrophages (between 5 and 7 per alveolum) [[PMID: 1496503]] [[PMID: 14512270]] [[PMID: 10051262]] [[Use 1 to fit ther data in mice]]
macsiz = 10; %Macrophage size in micras (21 microm of diameter, [[PMID: 9400735]])
stepm  = 2; %Movement of macrophages, 2 micrm/min de [[PMID: 26202827]]
clebac = 0.048; %Phagocytosys rate (min-1, calculated in Excel parameters calculation.xlsx (sheet: Phagocytosys rate) [[PMC266186]])
maxeat = 87; %Maximum number of bacteria attached to produce macrophage death [[PMID: 16177320]]
expos  = 105; %Time in minutes of exposition to pneumolysin required to trigger apoptosis in macrophages [[PMID: 26659062]]
alpha  = 0.0001*1e2; %Slope of the probability of macrophage death given the pneumolysin concentration calculated from [[PMID: 16177320]]
beta   = 4e-5; %Axis intercept of the probability of macrophage death given the pneumolysin concentration calculated from [[PMID: 16177320]]

%alpha       = 0; %%%%Full Mac
%beta        = 0; %%%%Full Mac
%nummac      = 0; %%%%No Mac

 %Monocytes
MonHalf = 6.62; %Monocyte half-life in hours. [[PMID: 3404972]]
%Assumed parameters based on simulations behavior
TrGra    = 1; %Distance to sense the metabolic gradient (cell units) (1.5 makes the macrophages decrease the bacteria optimally)
antigens = 10; %Number of antigens presented by bacteria to the macrophages. Higher than 30 produce small variability in the MCP1 profile in the model.
step1    = 0.1; %Movemenet rate in the sessile phase, assumed
step2    = 3; %Movemenet rate in the mobile phase, assumed
%Hocke (Inflamaci\F3n/Neutrophils/Material/Data/03&05) FIT
maxDam  = 0.7; %Maximal damage in the alveolus
barrDam = 2; %Barrier damage constant by neutrophils (1)
barrRec = 1; %Barrier restoration constant by neutrophils (0.1)
%Geraldine (Inflamaci\F3n/Neutrophils/Material/Data/01) FIT
 %Cell recruitment
load SolutionCalibration.mat %Best fit
KMonRec   = par_pop_tot(1,1); %Kinetic constant of monocyte recruitment (2e2)
ThMonRec  = par_pop_tot(2,1); %Threthold to recruit monocytes (1e-1) 0.4
MaxMonRec = par_pop_tot(3,1); %Maximal monocyte recruitment rate (4)
KNeuRec   = par_pop_tot(4,1); %Kinetic constant of neutrophils recruitment (2e2)
ThNeuRec  = par_pop_tot(5,1); %Threthold to recruit neutrophils (1e-1) 1.5
MaxNeuRec = par_pop_tot(6,1); %Maximal neutrophils recruitment rate (8)
NeuHalf   = par_pop_tot(7,1); %Neutrophils half-life in hours. (6.62)
Damagew   = par_pop_tot(8,1); %Weitgh og damage on the recruitment of neutrophils (20).
 %Bacteria
ChCa     = par_pop_tot(9,1); %Threshold of the effect of the capsule on change of phase, between 0 and 1. (0.5) (#par: 25)
halfCaps = par_pop_tot(10,1); %Capsule half time to maximal production (hours) (48) (#par: 16)
probS    = par_pop_tot(11,1); %Probability of not being interchanged between phases (0.999) A lower value stablish the infection with low probability (#par: 9)
propDea  = par_pop_tot(12,1); %Probability of bacteria to die because of complement and antibiotics (0.01) (#par: 26) Calculate from EC50
% [x,y,z,TRI,trio,Cen,Tra,Te]           = defineIco(2,ff,AlvRad); %Define the icosaedron parameters
load('dataIco.mat','x','y','z','TRI','trio','Cen','Tra','Te') %Load the icosaedron parameters
Pstru.movie                           = movie; %If 1 show results and save movie
Pstru.pantalla                        = pantalla; %If 1 show the results in command windows
Pstru.plotTime                        = plotTime; %If 1 plots the dynamics of the variables
Pstru.iteplot                         = iteplot; %Number of iteration per plot
Pstru.FN                              = FN; %Factor to change the units of MCP-1 to ng/ml. (normalized to 1600 pg/ml MCP-1 for 7 bacteria per alveolus [[DOI: 10.4049/jimmunol.0804096]])
Pstru.FT                              = FT; %Final time for the model in hours
Pstru.onoff                           = onoff; %Turn off the signal from MCP-1 to the alveolar macrophages 
Pstru.liquid                          = liquid; %Lining liquid width in microm from Figure 6A [[PMID: 17290033]]
Pstru.alvEnt                          = alvEnt; %Indexes of the alveolus entry. Estimated from [[PMID: 27695315]]
Pstru.x                               = x; %x coordinates of the icosaedron 
Pstru.y                               = y; %y coordinates of the icosaedron 
Pstru.z                               = z; %z coordinates of the icosaedron
Pstru.exit                            = exit; %Angle that define the border of the alveolus entry
Pstru.TRI                             = TRI; %Variable containing the nodes of the triangles of the icosaedron (every cell is composed by 4 triangles to fit the area correspondence [[PMID: 1540387]])
Pstru.trio                            = trio; %Variable containing the neighbour triangles
Pstru.Te                              = Te; %Variable containing the epicentres of the triangles
Pstru.Cen                             = Cen; %Variable containing the origin of the axis defined by the triangles
Pstru.Tra                             = Tra; %Variable containing the transforming matrix of the axis defined by the triangles
Pstru.AlvRadD                         = AlvRad; %Alveolus radious for plotting
Pstru.N                               = length(TRI(:,1)); %Numer of epithelial cells per alveolus
Pstru.numEQS                          = numEQS; %Number of variables in the signalling pathway model
Pstru.numEQS2                         = numEQS2; %Number of variables in the signalling pathway model
tiempo                                = 0:incre/60:FT; %Time for integration of the model
Pstru.growth                          = growth*pars(8); %Bacterial growth
Pstru.pars                            = pars; %Vector of tissue level parameters
Pstru.pars2                           = pars2; %Vector of cellular level parameters
Pstru.cel                             = Cel; %Microm of epithelial cell (30 microM [[PMID: 25360787 & PMID: 7611375]])
Pstru.Inrad                           = sqrt(AlvRad^2 - (Cel/2)^2); %Distance from the centre of the alveolus to the sizes of the icosaedron
Pstru.AlvRad                          = Pstru.Inrad - Pstru.liquid; %Introduce the elements in the inner side of the alveolus.
Pstru.dimens                          = (Pstru.cel*Pstru.N)/2; %Dimension of the alveoli in micrometers from Bionumbers (11 from 121 cells)
Pstru.nb                              = numbac; %Initial number of bacteria (11 by default) [[normalized to 1 macrophage according to data from Berlin]]
Pstru.fuera                           = fuera; %Bacteria leaving the alveolus
Pstru.Ndelay                          = Ndelay;
Pstru.nummac                          = round(nummac*pars(2)); %Number of macrophages, approximation from Bionumbers
Pstru.nummac0                         = Pstru.nummac; %Initla number of macrophages
Pstru.nummon                          = nummon; %Initial no of monocytes 
Pstru.nummon0                         = 0; %Initla number of macrophages
Pstru.numneu                          = numneu; %Initial no of neutrophils
Pstru.numneu0                         = 0; %Initial no of neutrophils
Pstru.matriz                          = zeros(1,numEQS*Pstru.N); %Initial conditions for the ODE model
Pstru.matriz(1,1:Pstru.N)             = 1; %Initial conditions for IRAK1
Pstru.matriz(1,2*Pstru.N+1:3*Pstru.N) = 1; %Initial conditions for IKK
Pstru.matriz(1,6*Pstru.N+1:7*Pstru.N) = 1; %Initial conditions for IkBa
Pstru.intramac                        = zeros(Pstru.nummac,numEQS2); %Initial conditions for the macrophage ODE model
Pstru.intramac([1,3,7])               = 1; %Initial conditions for IRAK1, IKK abd IkBa
Pstru.intramon                        = cell(numneu,1); %Initial conditions for the macrophage ODE model
Pstru.intramon(:)                     = {zeros(1,numEQS2)}; %Initial conditions for the macrophage ODE model
Pstru.intraneu                        = zeros(numneu,Pstru.Ndelay); %Initial conditions for the macrophage ODE model
con                                   = 0; %Countinf the iterationf for the output variables
tstep                                 = 0; %Counting the time steps between models
Pstru.baceat                          = 0; %Register of eaten bacteria
Pstru.out                             = 0; %Initial number of bacteria spreaded
Pstru.n                               = 0; %Initial number of iterations in minutes
Pstru.nab                             = 0; %Initial number of iterations after antibiotics in minutes
Pstru.nstop                           = 0; %Counting stoping time between the models
Pstru.final                           = 0; %Variable to stop the simulation
Pstru.angview                         = 0; %Initial value of the angle view of the figure
Pstru.step1                           = step1*pars(5); %Step when bacteria is attached
Pstru.step2                           = step2*pars(6); %Step when bacteria is floating
Pstru.step3                           = step3*pars(7); %Step while moved through the lining liquid
Pstru.step                            = ones(Pstru.nb,1)*Pstru.step2; %All bacteria start in the mobile phase
Pstru.nbF                             = Pstru.nb;  %All bacteria start in the mobile phase
Pstru.nbA                             = 0;  %All bacteria start in the mobile phase
[posx,posy,posz]                      = sph2cart(rand(Pstru.nb,1)*2*pi,random('normal',-(pi/4),pi/8,Pstru.nb,1),Pstru.AlvRad*ones(Pstru.nb,1)); %Initial location of bacteria
[macx,macy,macz]                      = sph2cart(rand(Pstru.nummac,1)*2*pi,rand(Pstru.nummac,1)*(Pstru.exit+pi/2) - pi/2,Pstru.AlvRad*ones(Pstru.nummac,1)); %Initial location of macrophages
Pstru.pos                             = [posx,posy,posz]; %Initial location of bacteria
Pstru.probAB                          = probAB; %Probabolity of survive 24 hours in presense of antibiotics
Pstru.maxprobAB                       = maxprobAB; %Maximal probability of survival in presence of antibiotics
Pstru.antibHour                       = antibHour; %Time the antibiotics are introduced
Pstru.antibi                          = antibi; %Antobiotics concentration
Pstru.antibiK                         = antibiK; %Antibiotics decay constant
Pstru.divBac                          = divBac; %Divergence respecting the original bacteria after dividing
Pstru.mac                             = [macx,macy,macz]; %Initial location of macrophages
Pstru.mon                             = zeros(0,3); %Initial location of monocytes
Pstru.neu                             = zeros(0,3); %Initial location of neutrophils
Pstru.Maclife                         = ones(Pstru.nummac,1); %Initial value of probability of stay alife for macrophages
Pstru.MaclifeT                        = Pstru.Maclife;
Pstru.MaclifeM                        = ones(Pstru.nummon,1); %Initial value of probability of stay alife for monocytes
Pstru.MaclifeMT                       = Pstru.MaclifeM;
Pstru.MaclifeN                        = ones(Pstru.numneu,1); %Initial value of probability of stay alife for neutrophils
Pstru.MaclifeNT                       = Pstru.MaclifeN;
Pstru.DeaMac                          = Pstru.Maclife*0 + 1; %Follow the death macrophages
Pstru.DeaMon                          = Pstru.MaclifeM*0 + 1; %Follow the death monocytes
Pstru.DeaNeu                          = Pstru.MaclifeN*0 + 1; %Follow the death neutrophils
Pstru.MonHalf                         = MonHalf; %Monocyte half-life
Pstru.neat                            = zeros(1,Pstru.nummac); %Intrinsic macrophage time for bacteria phagocytosis
Pstru.neatM                           = zeros(1,Pstru.nummon); %Intrinsic macrophage time for bacteria phagocytosis
Pstru.neatN                           = zeros(1,Pstru.numneu); %Intrinsic macrophage time for bacteria phagocytosis
Pstru.eaten                           = zeros(1,Pstru.nummac); %Register of eated bacteria by macrophages
Pstru.eatenM                          = zeros(1,Pstru.nummon); %Register of eated bacteria by monocytes
Pstru.eatenN                          = zeros(1,Pstru.numneu); %Register of eated bacteria by neutrophils
Pstru.div                             = round(rand(Pstru.nb,1)*Pstru.growth); %Initial stage of the cell cycle (from 0 to 200 mins.)
Pstru.infMon                          = ones(Pstru.nummon,1); %indicate the inflammatory state of monocytes
Pstru.CHEM{1}                         = zeros(1,Pstru.N); %Variable that contains MCP1
Pstru.CHEM{2}                         = zeros(1,Pstru.N); %Variable that contains pneumolysin
Pstru.CHEM{3}                         = zeros(1,Pstru.N); %Variable that contains IL8
Pstru.CHEM{4}                         = zeros(1,Pstru.N); %Variable that contains the barrier damage
Pstru.CHEM{5}                         = zeros(1,Pstru.N); %Variable that contains CXCL5
Pstru.dif                             = dif*pars(3); %Variable of diffusion constants
Pstru.IndexSpat                       = IndexSpat; %Logical vector for selecting diffusing variables
Pstru.antigens                        = antigens*pars(4); %Antigens recongized in each bacteria per epithelial cells
Pstru.probS                           = probS*pars(9); %Probability of changing the phase for bacteria
Pstru.ChCa                            = ChCa*pars(23); %Threshold of the effect of the capsule on change of phase, between 0 and 1.
Pstru.macsiz                          = macsiz; %Macrophage size
Pstru.maxbac                          = maxbac; %Number of bacteria that stops the simulation
Pstru.stepm                           = stepm*pars(10); %Macrophage step movement
Pstru.clebac                          = clebac*pars(11); %Phagocytosis rate
Pstru.maxeat                          = maxeat*pars(12); %Maximum number of bacteria eaten by macrophages at once
Pstru.alpha                           = alpha; %Slope of the probability of macrophage death given the pneumolysin concentration calculated from [[16177320]]
Pstru.beta                            = beta; %Axis intercept of the probability of macrophage death given the pneumolysin concentration calculated from [[16177320]]
Pstru.bacsize                         = bacsize; %Bacterium minimal size (microm). 
Pstru.capsize                         = capsize; %Increase in bacterial size by capsule (microm).
Pstru.halfCaps                        = halfCaps*pars(14); %Half time of capsule production
Pstru.TrGra                           = TrGra*pars(13); %Distance to sense the metabolic gradient (cell units) (1.5 makes the macrophages decrease the bacteria optimally)
Pstru.ff                              = ff; %Figure index
Pstru.pneumo1                         = pneumo1; %Pneumolysin production rate before 15 hours
Pstru.pneumo2                         = pneumo2; %Pneumolysin production rate after 15 hours
Pstru.pneumotime1                     = pneumotime1; %Threshold defined by data [[PMID: 2097494]]
Pstru.pneumotime2                     = pneumotime2; %Time of transition from pneumolysin rates
Pstru.monCount                        = zeros(nummon,1); %Define the counter of monocytes life
Pstru.neuCount                        = zeros(numneu,1); %Define the counter of neutrophils life
Pstru.conplot                         = 0; %Count the number of iteration inside the plotting loop
Pstru.condyn                          = 0; %Count the number of iteration inside the dynamics loop
Pstru.expos                           = expos; %Time in minutes of exposition to pneumolysin required to trigger apoptosis in macrophages (fit)
Pstru.neuD                            = zeros(0,3); %Initial position of death neutrophils
Pstru.interPlot                       = interPlot;
Pstru.maxDam                          = maxDam;
Pstru.barrDam                         = barrDam*pars(25); %Barrier damage constant by neutrophils 
Pstru.barrRec                         = barrRec*pars(26); %Barrier restoration constant by neutrophils 
Pstru.TotalVar                        = zeros(1,10); %Create the raviable to plot the dynamics of the variables
Pstru.KMonRec                         = KMonRec*pars(15);%Kinetic constant of monocyte recruitment 
Pstru.ThMonRec                        = ThMonRec*pars(16); %Threthold to recruit monocytes          
Pstru.MaxMonRec                       = MaxMonRec*pars(17); %Maximal monocyte recruitment rate
Pstru.KNeuRec                         = KNeuRec*pars(18); %Kinetic constant of neutrophils recruitment 
Pstru.ThNeuRec                        = ThNeuRec*pars(19); %Threthold to recruit neutrophils 
Pstru.MaxNeuRec                       = MaxNeuRec*pars(20); %Maximal neutrophils recruitment rate 
Pstru.NeuHalf                         = NeuHalf*pars(21); %neutrophils half-life
Pstru.Damagew                         = Damagew*pars(22); %Weitgh of damage on the recruitment of neutrophils.
Pstru.varNames                        = {'Bac','Mac','Mon','aMon','Neu','MCP1','IL8','Pneu','Dam','Rep'}; %Variables names for printing
%Output variables
T       = zeros(FT*6,1); %Time
NBa     = zeros(FT*6,1); %Number of bacteria attached
NBf     = zeros(FT*6,1); %Number of bacteria floating
NB      = zeros(FT*6,1); %Number of bacteria
NUMMAC  = zeros(FT*6,1); %Number of macrophages
NUMMON  = zeros(FT*6,1); %Number of monocytes
NUMNEU  = zeros(FT*6,1); %Number of neutrophils
DAMAGE  = zeros(FT*6,Pstru.N); %Barrier damage
PROBAB  = zeros(FT*6,1); %Probability of survival
MACLIFE = zeros(FT*6,Pstru.nummac); %Macrophage life
MCP1T   = zeros(FT*6,Pstru.N); %MCP1 chemokine
CXCL5T  = zeros(FT*6,Pstru.N); %CXCL5 chemokine
PneumoT = zeros(FT*6,Pstru.N); %Pneumolysin
IL8T    = zeros(FT*6,Pstru.N); %IL8
OUTBAC  = zeros(FT*6,1); %Bacteria leaving the alveolus
if Pstru.movie == 1
    Pstru.writerObj1           = VideoWriter('AlveolusRound.avi'); %Create a movie
    Pstru.writerObj1.FrameRate = 3*(10/Pstru.iteplot); %Define the frame rate
    open(Pstru.writerObj1); %Open the movie
else
    Pstru.writerObj1 = []; %Create a movie
end
%% Main loop of the model
tic %Start counting time
while (tstep < tiempo(end))
    tcurrent = toc;
    if tcurrent > Pstru.tmax
        return
    end
    %Run the models in steps
    tinit       = Pstru.nstop/60; %Initial time for the time step between models
    Pstru       = bacsMulti(Pstru); %Run the bacteria model
    Pstru.nstop = Pstru.nstop + incre; %Count the time step between models
    tstep       = Pstru.nstop/60; %In hours
    if tstep > tiempo(end)
        tstep = tiempo(end); %Cut the time to the maximum
    end
    tspan    = tinit:incre/60:tstep; %Integration interval
    LastMac  = zeros(Pstru.nummac,1); %Define the variable for the last stage of the intracellular macrophage model
    LastMon1 = zeros(Pstru.nummon,1); %Define the variable for the last stage of the pro-inflammatory intracellular monocyte model
    LastMon2 = zeros(Pstru.nummon,1); %Define the variable for the last stage of the anti-inflammatory intracellular monocyte model
    LastNeu  = zeros(Pstru.numneu,1); %Define the variable for the last stage of the intracellular neutrophil model
    for m = 1:Pstru.nummac
        [~,ymac]            = feval(solver,@celleqs,tspan,Pstru.intramac(m,:),[],Pstru,Pstru.eaten(m)); %Run the macrophage cellular model
        Pstru.intramac(m,:) = ymac(end,:); %Put last stage into fist step
        LastMac(m,1)        = ymac(end,8); %Saves the last stage of the intracellular macrophage model
    end
    for m = 1:Pstru.nummon
        if Pstru.infMon(m) == 1
            [~,ymon1]         = feval(solver,@celleqs,tspan,Pstru.intramon{m},[],Pstru,Pstru.eatenM(m)); %Run the pro-inflammatory monocyte cellular model
            Pstru.intramon(m) = {ymon1(end,:)}; %Put last stage into fist step
            LastMon1(m,1)     = ymon1(end,8); %Saves the last stage of the intracellular monocyte model
        else
            [~,ymon2]         = feval(solver,@barrDamage,tspan,0,[],Pstru,0); %Run the anti-inflammatory monocyte cellular model
            Pstru.intramon(m) = {ymon2(end,:)}; %Put last stage into fist step
            LastMon2(m,1)     = ymon2(end,end); %Saves the last stage of the intracellular monocyte model            
        end
    end
    for m = 1:Pstru.numneu
        [~,yneu]            = feval(solver,@barrDamage,tspan,0,[],Pstru,1); %Run the neutrophil cellular model
        Pstru.intraneu(m,:) = yneu(end,:); %Put last stage into fist step
        LastNeu(m,1)        = yneu(end,end);%Saves the last stage of the intracellular neutrophil model
    end
    Pstru.IL8mac = zeros(Pstru.N,1); %Define the variable for the IL8 production by macrophages
    Pstru.IL8mon = zeros(Pstru.N,1); %Define the variable for the IL8 production by monocytes
    Pstru.BarDam = zeros(Pstru.N,1); %Define the variable for the barrier damage by neutrophils
    Pstru.BarRec = zeros(Pstru.N,1); %Define the variable for the barrier restoration by anti-inflammatory monocytes
    if Pstru.nummac > 0
        Pstru.IL8mac(Pstru.triMac(Pstru.triMac ~= 0)) = LastMac(Pstru.triMac ~= 0); %Insert the IL8 production by macrophages
    end
    if Pstru.numneu > 0
        Pstru.BarDam(Pstru.triNeu(Pstru.triNeu ~= 0)) = LastNeu(Pstru.triNeu ~= 0); %Insert the barrier damage by neutrophils
    end
    if Pstru.nummon > 0
        Pstru.IL8mon(Pstru.triMon(Pstru.triMon ~= 0))                     = LastMon1(Pstru.triMon ~= 0); %Insert the IL8 production by monocytes
        Pstru.BarRec(Pstru.triMon(Pstru.triMon ~= 0 & Pstru.infMon == 0)) = LastMon2(Pstru.triMon ~= 0 & Pstru.infMon == 0); %Insert the barrier restoration by anti-inflammatory monocytes
    end
    Pstru.IL8m = Pstru.IL8mon + Pstru.IL8mac; %Aggregate the IL8 values from macrophages and monocytes
    [t,y]      = feval(solver,@modeleqs,tspan,Pstru.matriz,[],Pstru); %Run the epithelial cell model
    %Create the output variables
    MCP1           = transpose(y(end,8*Pstru.N+1:9*Pstru.N)); %Takes MCP1 concentration
    pneumo         = transpose(y(end,9*Pstru.N+1:10*Pstru.N)); %Takes pneumolysin concentration
    IL8            = y(end,10*Pstru.N+1:11*Pstru.N); %Takes IL8 concentration
    Damage         = y(end,11*Pstru.N+1:12*Pstru.N); %Takes the barries damage
    CXCL5          = y(end,13*Pstru.N+1:14*Pstru.N); %Takes the CXCL5
    Pstru.CHEM{1}  = MCP1; %Include MCP1 in the chemokines variable
    Pstru.CHEM{2}  = pneumo; %Include pneumolysin in the chemokines variable
    Pstru.CHEM{3}  = IL8; %Include IL8 in the chemokines variable
    Pstru.CHEM{4}  = Damage; %Include damage in the chemokines variable
    Pstru.CHEM{5}  = CXCL5; %Include CXCL5 in the chemokines variable
    con            = con + 1; %Repetitions of the submodels
    T(con)         = t(end); %Time
    NB(con)        = Pstru.nb; %Number of bacteria 
    NBa(con)       = Pstru.nbA; %Number of bacteria attached
    NBf(con)       = Pstru.nbF; %Number of bacteria floating
    NUMMAC(con)    = Pstru.nummac; %Number of macrophages
    NUMMON(con)    = Pstru.nummon; %Number of monocytes
    NUMNEU(con)    = Pstru.numneu; %Number of neutrophils
    DAMAGE(con,:)  = Damage; %Barrier damage
    PROBAB(con)    = mean(Pstru.probAB); %Probability of survival
    MACLIFE(con,:) = transpose(Pstru.MaclifeT); %Macrophage life
    MCP1T(con,:)   = MCP1; %MCP1 chemokine
	CXCL5T(con,:)  = CXCL5; %CXCL5 chemokine
    PneumoT(con,:) = pneumo; %Pneumolysin
    IL8T(con,:)    = IL8; %IL8 chemokine
    OUTBAC(con)    = Pstru.fuera; %Bacteria leaving the alveolus (cummulative)
end
%% Finalizing the simulation
%Define the variable of alveolar infection
if NB(end) > Bcrit
    INF = 1; %It grouos in 1 if bacteria growth above the limit
else
    INF = 0; %It groups in 0 if  bacteria growth below the limit
end
%Create the movie
if Pstru.movie == 1
    close(Pstru.writerObj1); %Close video
end
tfinal = toc; %Save the time for one run
if (exist('indice','var') == 1 && numel(indice) ~= 0)
    nombreFile = strcat('SingleSol_',num2str(indice),'.mat'); %Create the file name
    nbA        = sum(NBa,2);
    nbF        = sum(NBf,2);
    nummac     = sum(NUMMAC,2);
    nummon     = sum(NUMMON,2);
    numneu     = sum(NUMNEU,2);
    ParsSave   = [KMonRec;ThMonRec;MaxMonRec;KNeuRec;ThNeuRec;MaxNeuRec;NeuHalf];
    dado       = [];
    save(nombreFile,'T','nbA','nbF','nummac','nummon','numneu','tfinal','ParsSave','dado')  %To calculate one solution in sevelar alveoli
end
end
%% Bacteria model function
function Pstru = bacsMulti(Pstru)
%% Biological parameters
Pstru.capsule = (Pstru.n/(Pstru.n + (Pstru.halfCaps*60))); %Define amount of capsule of bacteria (between 0 and 1)
Pstru.bacsize = Pstru.bacsize + Pstru.capsule*Pstru.capsize; %Increase size of bacteria after capsule production
Pstru.matBac  = zeros(1,Pstru.N); %Define the bacteria matrix
Pstru.indMac  = ones(Pstru.nummac,3); %Initial value for indexes of macrophages
Pstru.indMon  = ones(Pstru.nummon,3); %Initial value for indexes of monocytes
Pstru.indNeu  = ones(Pstru.numneu,3); %Initial value for indexes of monocytes
Pstru.triMac  = zeros(Pstru.nummac,1); %Initial value for triangle location of macrophages
Pstru.triMon  = zeros(Pstru.nummon,1); %Initial value for triangle location of monocytes
Pstru.triNeu  = zeros(Pstru.numneu,1); %Initial value for triangle location of neutrophils
MCP1          = Pstru.CHEM{1}; %Define the MCP1 chemokine
Pneumo        = Pstru.CHEM{2}; %Define the pneumolysin
IL8           = Pstru.CHEM{3}; %Define the IL8
Damage        = Pstru.CHEM{4}; %Define barrier damage
CXCL5         = Pstru.CHEM{5}; %Define the CXCL5 chemokine
%% Display parameters
iteplot = Pstru.iteplot; %Iterations of plotting
% set(1, 'Visible', 'off'); %Prevents the figure to be displayed
%% Iterations loop
%while (Pstru.nb >= 1 && Pstru.nb < Pstru.maxbac && Pstru.n < Pstru.nstop) %%%%
while (Pstru.nb < Pstru.maxbac && Pstru.n < Pstru.nstop)
    %% Display the current situation
    if mod(Pstru.n,iteplot) == 0 %Iterations to plot
        if Pstru.movie == 1 %Module to create the movie
            Pstru.conplot        = Pstru.conplot + 1; %Count the number of iteration inside the plotting loop
            MCP1(Pstru.alvEnt)   = 0; %Define the entry of the alveolus to zero.
            Pneumo(Pstru.alvEnt) = 0; %Define the entry of the alveolus to zero.
            IL8(Pstru.alvEnt)    = 0; %Define the entry of the alveolus to zero.
            Damage(Pstru.alvEnt) = 0; %Define the entry of the alveolus to zero.
            CXCL5(Pstru.alvEnt)  = 0; %Define the entry of the alveolus to zero.
            if Pstru.conplot < 11
                col    = MCP1/1e-4; %Normalize the MCP1 concentrations
                coltit = 'MCP1';
                mapa   = colormap('winter'); %Define the colormap
            elseif Pstru.conplot < 21
                col    = Pneumo/1; %Normalize the MCP1 concentrations
                coltit = 'Pneumolysin';
                mapa   = colormap('summer'); %Define the colormap
            else
                col    = IL8/1e-6; %Normalize the MCP1 concentrations
                coltit = 'IL-8';
                mapa   = colormap('spring'); %Define the colormap
                if Pstru.conplot > 30
                    Pstru.conplot = 0; %Reset the counter
                end
            end
            col2                               = Damage/max(Damage);
            col2(col2./col2 ~= 1)              = 0;
            col2(col2 > 1)                     = 1; %Prevent values higher than 1
            col2(col2 < 0)                     = 0; %Prevent values lower than 0
            col(col > 1)                       = 1; %Prevent values higher than 1
            col(col < 0)                       = 0; %Prevent values lower than 0
            indice                             = fix(col*length(mapa(:,1)) + 1); %Generate the index to take colos from the map
            indice(indice > length(mapa(:,1))) = length(mapa(:,1)); %Prevent indexes higker than the length of the map
            col                                = mapa(indice,:); %Take color from the map
            for tr = 1:length(Pstru.TRI(:,1)) %Loop through the triangles of the icosaedron
                figure(Pstru.ff) %Plot the figure
                if sum(tr == Pstru.alvEnt) == 0 %Dont plot the entry of the alveolus
                    trisurf(Pstru.TRI(tr,:),Pstru.x,Pstru.y,Pstru.z,'FaceColor',col(tr,:),'EdgeColor',col2(tr)*[1 0 0],'LineWidth',1); %Plot the triangles
                end
                hold on %Keep the figure
                colbar = colorbar; %Add color bar
                title(colbar,coltit) %Add title to color bar
                caxis([0 1]) %Define color limits
            end
            [theta1,phi1,~]                             = cart2sph(Pstru.mac(:,1),Pstru.mac(:,2),Pstru.mac(:,3));  %Create the coordinates for the macrophage markers
            [theta2,phi2,~]                             = cart2sph(Pstru.pos(:,1),Pstru.pos(:,2),Pstru.pos(:,3)); %Create the coordinates for the bacteria markers
            [theta3,phi3,~]                             = cart2sph(Pstru.mon(:,1),Pstru.mon(:,2),Pstru.mon(:,3)); %Create the coordinates for the monocytes markers
            [theta4,phi4,~]                             = cart2sph(Pstru.neu(:,1),Pstru.neu(:,2),Pstru.neu(:,3)); %Create the coordinates for the neutrophils markers
            [theta5,phi5,~]                             = cart2sph(Pstru.neuD(:,1),Pstru.neuD(:,2),Pstru.neuD(:,3)); %Create the coordinates for the deathneutrophils markers
            macPlot                                     = [theta1,phi1]; %Create the coordinates for the macrophage markers
            bacPlot                                     = [theta2,phi2]; %Create the coordinates for the bacteria markers
            monPlot                                     = [theta3,phi3]; %Create the coordinates for the monocytes markers
            neuPlot                                     = [theta4,phi4]; %Create the coordinates for the neutrophils markers
            neuDPlot                                    = [theta5,phi5]; %Create the coordinates for the death neutrophils markers
            [macPlot(:,1),macPlot(:,2),macPlot(:,3)]    = sph2cart(macPlot(:,1),macPlot(:,2),Pstru.AlvRadD); %Create the coordinates for the macrophage markers
            [bacPlot(:,1),bacPlot(:,2),bacPlot(:,3)]    = sph2cart(bacPlot(:,1),bacPlot(:,2),Pstru.AlvRadD); %Create the coordinates for the bacteria markers
            [monPlot(:,1),monPlot(:,2),monPlot(:,3)]    = sph2cart(monPlot(:,1),monPlot(:,2),Pstru.AlvRadD); %Create the coordinates for the monocytes markers
            [neuPlot(:,1),neuPlot(:,2),neuPlot(:,3)]    = sph2cart(neuPlot(:,1),neuPlot(:,2),Pstru.AlvRadD); %Create the coordinates for the neutrophils markers
            [neuDPlot(:,1),neuDPlot(:,2),neuDPlot(:,3)] = sph2cart(neuDPlot(:,1),neuDPlot(:,2),Pstru.AlvRadD); %Create the coordinates for the neutrophils markers
            scatter3(macPlot(:,1),macPlot(:,2),macPlot(:,3),100,'filled','MarkerFaceColor',[0 0.8 0.8]) %Plot macrophages outside the alveolus
            scatter3(bacPlot(:,1),bacPlot(:,2),bacPlot(:,3),10,'filled','MarkerFaceColor',[0.8 0 0]) %Plot bacteria outside the alveolus
            scatter3(monPlot(:,1),monPlot(:,2),monPlot(:,3),100,'filled','MarkerFaceColor',[0 0.8 0]) %Plot monocytes outside the alveolus
            scatter3(neuPlot(:,1),neuPlot(:,2),neuPlot(:,3),100,'filled','MarkerFaceColor',[0.8 0.8 0]) %Plot neutrophils outside the alveolus
            scatter3(neuDPlot(:,1),neuDPlot(:,2),neuDPlot(:,3),100,'filled','MarkerFaceColor',[0.5 0.5 0.5]) %Plot neutrophils outside the alveolus
            title(strcat('Bacteria=',num2str(Pstru.nb),'(',num2str(Pstru.pars(1)),')',' Eaten bacteria=',...
                num2str(Pstru.baceat),' Hours=',num2str(floor(Pstru.n/60)),'/10h',' Capsule=',...
                num2str(round(Pstru.capsule*10)/10),'/1')) %Number of bacteria in the title
            ax          = gca; %Take figure
            ax.FontSize = 8; %Change font size
            xlim([-Pstru.AlvRadD Pstru.AlvRadD]) %Define the limits for the x axis
            ylim([-Pstru.AlvRadD Pstru.AlvRadD]) %Define the limits for the y axis
            zlim([-Pstru.AlvRadD Pstru.AlvRadD]) %Define the limits for the z axis
            axis off %Remove the axis
            Pstru.angview = Pstru.angview + 1; %Move the view
            view(Pstru.angview,-30) %Define the angle view
            figure(Pstru.ff) %Plot the figure
            hold off %Stop keeping the figure
            frame1 = getframe(gcf); %Create the frame
            writeVideo(Pstru.writerObj1,frame1); %Save the frame
            drawnow %Plot the figure now
        end
        if Pstru.pantalla == 1
            Ctime = clock; %Current time
            Itime = Pstru.Itime; %Initial time
            if round(Itime(5)) < 10
                minutosI = strcat('0',num2str(round(Itime(5)))); %Add a 0 if minutes are less than 10
            else
                minutosI = num2str(round(Itime(5))); %Save the time for minutes higher tha 10
            end
            if round(Ctime(5)) < 10
                minutosC = strcat('0',num2str(round(Ctime(5)))); %Add a 0 if minutes are less than 10
            else
                minutosC = num2str(round(Ctime(5))); %Save the time for minutes higher tha 10
            end    
            horaI = strcat(num2str(Itime(4)),':',minutosI); %Save the time as a string
            horaC = strcat(num2str(Ctime(4)),':',minutosC); %Save the time as a string
            fprintf('Run: %g\nIteration: %g minutes (%g hours)\nCapsule: %g\nBacteria BAL: %g\nBacteria lungs: %g\nEaten bacteria: %g\nMacrophages: %g\nMonocytes: %g\nAnti-inf. monocytes: %g\nNeutrophils: %g\nMCP1: %g\nIL8: %g\nPneunolysin: %g\nBarrier damage: %g\nAntibiotic resistance: %g\nInit time: %s\nCurrent time: %s\n',...
                Pstru.interPlot,Pstru.n,floor(Pstru.n/60),Pstru.capsule,Pstru.nbF,Pstru.nbA,Pstru.baceat,Pstru.nummac,Pstru.nummon,sum(Pstru.infMon==0),Pstru.numneu,sum(MCP1),sum(IL8),sum(Pneumo),sum(Damage),mean(Pstru.probAB),horaI,horaC) %Display the results in the screen
            fprintf('\n') %Jump one line
        end
        if Pstru.plotTime == 1
            Pstru.condyn = Pstru.condyn + 1;
            Pstru.TotalVar(Pstru.condyn,1)  = Pstru.nb;
            Pstru.TotalVar(Pstru.condyn,2)  = Pstru.nummac;
            Pstru.TotalVar(Pstru.condyn,3)  = Pstru.nummon;
            Pstru.TotalVar(Pstru.condyn,4)  = sum(Pstru.infMon==0);
            Pstru.TotalVar(Pstru.condyn,5)  = Pstru.numneu;
            Pstru.TotalVar(Pstru.condyn,6)  = sum(MCP1);
            Pstru.TotalVar(Pstru.condyn,7)  = sum(IL8);
            Pstru.TotalVar(Pstru.condyn,8)  = sum(Pneumo);
            Pstru.TotalVar(Pstru.condyn,9)  = sum(Damage);
            figure(Pstru.ff + 1) %Plot the figure
            for nplot = 1:10
                subplot(2,5,nplot)
                hold on
                plot(10*(1:Pstru.condyn),Pstru.TotalVar(:,nplot),'-b')
                xlabel('Minutes')
                title(Pstru.varNames{nplot})
                drawnow
            end
        end
    end    
    %% Bacterial saturable growth
    Pstru.n = Pstru.n + 1; %Count the iterations (minutes)
    if Pstru.nb > 0
        Pstru.div                                           = Pstru.div + 1; %Increase the time for dividing
        crecen                                              = (Pstru.div >= Pstru.growth); %Decide which bacteria growth
        Pstru.div(crecen)                                   = 0; %Set the growth time to zero after dividing
        Pstru.div                                           = [Pstru.div;Pstru.div(crecen)]; %Doubling the number of bacteria
        Pstru.pos(Pstru.nb + 1:(Pstru.nb + sum(crecen)),:)  = Pstru.pos(crecen,:); %Bacteria divide
        Pstru.step(Pstru.nb + 1:(Pstru.nb + sum(crecen)),1) = Pstru.step(crecen,1); %Doubling the step vector
        Pstru.nb                                            = Pstru.nb + sum(crecen); %Doubling the number of bacteria
        r                                                   = (rand(sum(crecen),1)*2 - 1)*0; %Allows variations
        newprobAB                                           = Pstru.probAB(crecen) + Pstru.divBac*Pstru.probAB(crecen).*(rand(size(Pstru.probAB(crecen)))*2-1); %Inheritance of survival probability
        Pstru.probAB                                        = [Pstru.probAB;newprobAB]; %Doubling the probabilities with variations
        Pstru.probAB(Pstru.probAB < 0)                      = 0; %Set to 0 negative values
        Pstru.probAB(Pstru.probAB > Pstru.maxprobAB)        = Pstru.maxprobAB; %Set to maximal resistance higher values
    end
    %% Interchange between phases
    if Pstru.nb > 0 
        Pstru.step((rand(length(Pstru.step),1) > (Pstru.probS*(1 - Pstru.capsule*(Pstru.capsule >= Pstru.ChCa))) & Pstru.step == Pstru.step1),1)     = Pstru.step2; %Jump to the mobile phase
        Pstru.step((rand(length(Pstru.step),1) > (Pstru.probS*(Pstru.capsule*(Pstru.capsule >= Pstru.ChCa) - 1) + 1) & Pstru.step == Pstru.step2),1) = Pstru.step1; %Settle into the sessile phase
        Pstru.nbA                                                                                                                 = sum(Pstru.step == Pstru.step1); %Count the number of attached bacteria
        Pstru.nbF                                                                                                                 = sum(Pstru.step == Pstru.step2); %Count the number of floating bacteria
    else
        Pstru.nbA = 0; %Count the number of attached bacteria
        Pstru.nbF = 0; %Count the number of floating bacteria
    end
    %% Random movement of bacteria
    if Pstru.nb > 0
        d1                                             = (rand(Pstru.nb,1)*2 - 1); %Random angle 1
        d2                                             = (rand(Pstru.nb,1)*2 - 1); %Random angle 2
        [theta,phi,~]                                  = cart2sph(Pstru.pos(:,1),Pstru.pos(:,2),Pstru.pos(:,3)); %Tranform to spherical coordinates
        theta                                          = theta + rand(Pstru.nb,1).*(d1./abs(d1)).*asin(Pstru.step/Pstru.AlvRad); %Random angle 1
        phi                                            = phi + rand(Pstru.nb,1).*(d2./abs(d2)).*asin(Pstru.step/Pstru.AlvRad); %Random angle 2
        [Pstru.pos(:,1),Pstru.pos(:,2),Pstru.pos(:,3)] = sph2cart(theta,phi,Pstru.AlvRad); %Tranform to cartesian coordinates
    end
    %% Movement of macrophages
    [CelPos,CelTri,Pstru] = movement(Pstru.mac,Pstru.nummac,Pstru.triMac,Pstru,0);
    Pstru.mac      = CelPos;
    Pstru.triMac   = CelTri;
    %% Macrophages eat bacteria
    Pstru = phagocytosis(Pstru.mac,Pstru.nummac,Pstru.eaten,Pstru.neat,Pstru,0);
    %% Macrophages die because of pneumolysin
    if numel(Pstru.mac) ~= 0
        macKill                            = Pstru.triMac*0; %Define the vector of pneumolysin concentration on macrophages location
        macKill(Pstru.triMac ~= 0)         = Pneumo(Pstru.triMac(Pstru.triMac ~= 0)); %Obtain the pneumolysin concentration on macrophages location
        Pstru.Maclife                      = Pstru.Maclife.*exp(-(Pstru.alpha*macKill + Pstru.beta)); %Decrease of probability of macrophage to stay alife given a pneumolysin concentration, from Calculate Macrophage apoptosis.xlsx [[PMID: 16177320]]        
        probApo                            = Pstru.Maclife.^(1/Pstru.expos); %Assign probability to each step given the probability from [[PMID: 16177320]] Assume 60 minutes of exposition required    
        macKill2                           = zeros(Pstru.nummac0,1); %Define the total count of macrophages
        macKill2(Pstru.DeaMac == 1)        = macKill; %Assign alive macrophages to the total count of macrophages
        Pstru.MaclifeT                     = Pstru.MaclifeT.*exp(-(Pstru.alpha*macKill2 + Pstru.beta)); %Store probabilities of all macrophages
        probApo2                           = Pstru.MaclifeT.^(1/Pstru.expos); %Assign probability to each step given the probability from [[PMID: 16177320]] Assume 60 minutes of exposition required      
        probApo(macKill == 0)              = 1; %Define the empty macrophages as 1
        probApo2(macKill2 == 0)            = 1; %Define the empty macrophages as 1
        randApop                           = rand(length(probApo(:,1)),length(probApo(1,:))); %Random number for apoptosis
        randApop2                          = zeros(length(probApo2(:,1)),length(probApo2(1,:))); %Define the random number for the total count of macrophages
        randApop2(Pstru.DeaMac == 1)       = randApop; %Assign the random number on the total count of macrophages
        Pstru.mac(probApo < randApop,:)    = []; %Remove macrophages
        Pstru.neat(probApo < randApop)     = []; %Remove intrinsic time
        Pstru.triMac(probApo < randApop,:) = []; %Remove macrophage triangle locations
        Pstru.dist(:,probApo < randApop)   = []; %Remove distance to bacteria 
        Pstru.rcap1(:,probApo < randApop)  = []; %Repeat for all macrophages
        Pstru.indMac(probApo < randApop,:) = []; %Remove the IL1B matrix
        Pstru.eaten(probApo < randApop)    = []; %Remove the counter of eaten bacteria
        Pstru.Maclife(probApo < randApop)  = []; %Remove the life of macrophages
        Pstru.nummac                       = Pstru.nummac - sum(probApo < randApop); %Substract death macrophages from the count
        Pstru.DeaMac(probApo2 < randApop2) = 0; %Put zero on death macrophages           
    end
    %% Recruitment of monocytes
    MCP1T   = sum(MCP1); %Calculate the total concentration of chemokine in the alveolus
    valMon  = 0:Pstru.MaxMonRec; %Define the possible number of new cell recruited
    ProbMon = @(x,k,x0,L) (L*x0*exp(k*x))./(L + x0*(exp(k*x) - 1)); %Assign probability to recruitment rate for the corresponding chemokine value
    NumMon  = poisscdf(valMon,ProbMon(MCP1T,Pstru.KMonRec,Pstru.ThMonRec,Pstru.MaxMonRec)); %Calculate the probability of recruing different number of cells
    rMon    = rand; %Random value
    NewMon  = rMon > NumMon; %Calculate the number of cells recruited
    valMon  = valMon(NewMon); %Operate with the number of cells recruited
    if ~isempty(valMon)
        valMon = valMon(end); %Take the value of the number of cells recruited
    else
        valMon = 0; %Take the value of the number of cells recruited
    end
    Pstru.nummon                     = Pstru.nummon + valMon; %Add the number of cells recruited
    Pstru.nummon0                    = Pstru.nummon0 + valMon; %Add the number of cells recruited
    intramon0                        = zeros(1,Pstru.numEQS2); %Initial conditions for the Monocyte ODE model
    intramon0(:,[1,3,7])             = 1; %Initial conditions for IRAK1, IKK abd IkBa
    Pstru.infMon                     = [Pstru.infMon;ones(valMon,1)]; %Indicates the inflammatory state of monocytes
    Pstru.intramon(end+1:end+valMon) = {intramon0};
    [MonPosx,MonPosy,MonPosz]        = sph2cart(rand(valMon,1)*2*pi,rand(valMon,1)*(valMon+pi/2) - pi/2,Pstru.AlvRad*ones(valMon,1)); %Generate new position for recruited cells
    MonPos                           = [MonPosx,MonPosy,MonPosz]; %Cell position
    Pstru.mon                        = [Pstru.mon;MonPos]; %Add positions of recruited cells
    Pstru.monCount                   = [Pstru.monCount;zeros(valMon,1)]; %Add monocyte inner clock
    Pstru.eatenM                     = [Pstru.eatenM,zeros(1,valMon)]; %Add space for eaten bacteria
    Pstru.neatM                      = [Pstru.neatM,zeros(1,valMon)]; %Add space for time to eat bacteria
    Pstru.indMon                     = [Pstru.indMon;zeros(valMon,3)]; %Add space for indexes of recruited cells
    Pstru.MaclifeM                   = [Pstru.MaclifeM;ones(valMon,1)]; %Add space for recruited cells life
    Pstru.MaclifeMT                  = [Pstru.MaclifeMT;ones(valMon,1)]; %Add space for recruited cells life
    Pstru.DeaMon                     = [Pstru.DeaMon;ones(valMon,1)]; %Add space for counting death cells
    Pstru.triMon                     = [Pstru.triMon;ones(valMon,1)]; %Add space for monocyte location
    %% Movement of Monocytes
    [CelPos,CelTri,Pstru] = movement(Pstru.mon,Pstru.nummon,Pstru.triMon,Pstru,1); %Inputs: cell position, number of cells and triangle cell position
    Pstru.mon             = CelPos;
    Pstru.triMon          = CelTri;
    %% Monocytes eat bacteria
    Pstru = phagocytosis(Pstru.mon,Pstru.nummon,Pstru.eatenM,Pstru.neatM,Pstru,1);  
    %% Monocytes die because of pneumolysin
    if numel(Pstru.mon) ~= 0
        macKill                            = Pstru.triMon*0; %Define the vector of pneumolysin concentration on monocytes location
        macKill(Pstru.triMon ~= 0)         = Pneumo(Pstru.triMon(Pstru.triMon ~= 0)); %Obtain the pneumolysin concentration on monocytes location
        Pstru.MaclifeM                     = Pstru.MaclifeM.*exp(-(Pstru.alpha*macKill + Pstru.beta)); %Decrease of probability of monocytes to stay alife given a pneumolysin concentration, from Calculate Macrophage apoptosis.xlsx [[PMID: 16177320]]        
        probApo                            = Pstru.MaclifeM.^(1/Pstru.expos); %Assign probability to each step given the probability from [[PMID: 16177320]] Assume 60 minutes of exposition required    
        macKill2                           = zeros(Pstru.nummon0,1); %Keep death monocytes
        macKill2(Pstru.DeaMon == 1)        = 1; %Count death monocytes
        Pstru.MaclifeMT                    = Pstru.MaclifeMT.*exp(-(Pstru.alpha*macKill2 + Pstru.beta)); %Store probabilities of all monocytes  
        probApo2                           = Pstru.MaclifeMT.^(1/Pstru.expos); %Assign probability to each step given the probability from [[PMID: 16177320]] Assume 60 minutes of exposition required      
        probApo(macKill == 0)              = 1; %Define the empty monocytes as 0
        probApo2(macKill2 == 0)            = 1; %Define the empty monocytes as 0
        randApop                           = rand; %Random number for apoptosis
        Pstru.mon(probApo < randApop,:)    = []; %Remove monocytes
        Pstru.triMon(probApo < randApop,:) = []; %Remove monocytes triangle locations
        Pstru.dist(:,probApo < randApop)   = []; %Remove distance to bacteria 
        Pstru.rcap1(:,probApo < randApop)  = []; %Repeat for all monocytes
        Pstru.nummon                       = Pstru.nummon - sum(probApo < randApop); %Substract death monocytes from the count
        Pstru.eatenM(probApo < randApop)   = []; %Remove the counter of eaten bacteria
        Pstru.neatM(probApo < randApop)    = []; %Remove intrinsic time
        Pstru.indMon(probApo < randApop,:) = []; %Remove the IL1B matrix
        Pstru.MaclifeM(probApo < randApop) = []; %Remove the life of monocytes
        Pstru.DeaMon(probApo2 < randApop)  = 0; %Put zero on death monocytes   
        Pstru.intramon(probApo < randApop) = []; %Remove initial condition of monocytes
        Pstru.infMon(probApo < randApop)   = []; %Remove the inflammatory state of monocytes
        Pstru.monCount(probApo < randApop) = []; %Remove the inner clock of monocytes
    end
    %% Monocytes natural decay
    if numel(Pstru.mon) ~= 0
        Pstru.monCount = Pstru.monCount + 1;
        monCicle = fix(Pstru.monCount/Pstru.MonHalf) == Pstru.monCount/Pstru.MonHalf; %Set the monocytes that reach their half-life
        selDeat  = monCicle.*fix(rand(length(monCicle),1)*2); %Probability of 50% to die once the half-life is reached
        selDeat  = logical(selDeat); %Transform to logical
        if sum(selDeat) > 0
            Pstru.mon(selDeat,:)    = []; %Remove monocytes
            Pstru.triMon(selDeat,:) = []; %Remove monocytes triangle locations
            Pstru.dist(:,selDeat)   = []; %Remove distance to bacteria 
            Pstru.rcap1(:,selDeat)  = []; %Repeat for all monocytes
            Pstru.nummon            = Pstru.nummon - sum(selDeat); %Substract death monocytes from the count
            Pstru.eatenM(selDeat)   = []; %Remove the counter of eaten bacteria
            Pstru.neatM(selDeat)    = []; %Remove intrinsic time
            Pstru.indMon(selDeat,:) = []; %Remove the IL1B matrix
            Pstru.MaclifeM(selDeat) = []; %Remove the life of monocytes
            Pstru.DeaMon(selDeat)   = 0; %Put zero on death monocytes 
            Pstru.intramon(selDeat) = []; %Remove initial condition of monocytes
            Pstru.infMon(selDeat)   = []; %Remove the inflammatory state of monocytes
            Pstru.monCount(selDeat) = []; %Remove the inner clock of monocytes
        end
    end
    %% Recruitment of Neutrophils
    Chem     = sum(IL8) + sum(CXCL5); %Calculate the total concentration of chemokine in the alveolus %%%%
    valNeu   = 0:Pstru.MaxNeuRec; %Define the possible number of new cell recruited
    ProbNeu  = @(x,k,x0,L) (L*x0*exp(k*x))./(L + x0*(exp(k*x) - 1)); %Assign probability to recruitment rate for the corresponding chemokine value
    NumNeu   = poisscdf(valNeu,ProbNeu(Chem,Pstru.KNeuRec,Pstru.ThNeuRec,Pstru.MaxNeuRec)); %Calculate the probability of recruing different number of cells
    rNeu     = rand; %Random value
    NewNeu   = rNeu > NumNeu; %Calculate the number of cells recruited
    valNeu   = valNeu(NewNeu); %Operate with the number of cells recruited
    if ~isempty(valNeu)
        valNeu = valNeu(end); %Take the value of the number of cells recruited
    else
        valNeu = 0; %Take the value of the number of cells recruited
    end
    Pstru.numneu              = Pstru.numneu + valNeu; %Add the number of cells recruited
    Pstru.numneu0             = Pstru.numneu0 + valNeu; %Add the number of cells recruited
    intraneu0                 = zeros(valNeu,Pstru.Ndelay); %Initial conditions for the neutrophils ODE model
    Pstru.intraneu            = [Pstru.intraneu;intraneu0]; %Integrate the initial condition to the former condition
    [NeuPosx,NeuPosy,NeuPosz] = sph2cart(rand(valNeu,1)*2*pi,rand(valNeu,1)*(valNeu+pi/2) - pi/2,Pstru.AlvRad*ones(valNeu,1)); %Generate new position for recruited cells
    NeuPos                    = [NeuPosx,NeuPosy,NeuPosz]; %Cell position
    Pstru.neu                 = [Pstru.neu;NeuPos]; %Add positions of recruited cells
    Pstru.eatenN              = [Pstru.eatenN,zeros(1,valNeu)]; %Add space for eaten bacteria
    Pstru.neuCount            = [Pstru.neuCount;zeros(valNeu,1)]; %Add neutrophils inner clock
    Pstru.neatN               = [Pstru.neatN,zeros(1,valNeu)]; %Add space for time to eat bacteria
    Pstru.indNeu              = [Pstru.indNeu;zeros(valNeu,3)]; %Add space for indexes of recruited cells
    Pstru.MaclifeN            = [Pstru.MaclifeN;ones(valNeu,1)]; %Add space for recruited cells life
    Pstru.MaclifeNT           = [Pstru.MaclifeNT;ones(valNeu,1)]; %Add space for recruited cells life
    Pstru.DeaNeu              = [Pstru.DeaNeu;ones(valNeu,1)]; %Add space for counting death cells
    Pstru.triNeu              = [Pstru.triNeu;ones(valNeu,1)]; %Add space for monocyte location
    %% Movement of Neutrophils
    [CelPos,CelTri,Pstru] = movement(Pstru.neu,Pstru.numneu,Pstru.triNeu,Pstru,0); %Inputs: cell position, number of cells and triangle cell position
    Pstru.neu             = CelPos;
    Pstru.triNeu          = CelTri;
    %% Neutrophils eat bacteria
    Pstru = phagocytosis(Pstru.neu,Pstru.numneu,Pstru.eatenN,Pstru.neatN,Pstru,0); 
    %% Neutrophils die because of pneumolysin
    if numel(Pstru.neu) ~= 0
        macKill                            = Pstru.triNeu*0; %Define the vector of pneumolysin concentration on neutrophils location
        macKill(Pstru.triNeu ~= 0)         = Pneumo(Pstru.triNeu(Pstru.triNeu ~= 0)); %Obtain the pneumolysin concentration on neutrophils location
        Pstru.MaclifeN                     = Pstru.MaclifeN.*exp(-(Pstru.alpha*macKill + Pstru.beta)); %Decrease of probability of neutrophils to stay alife given a pneumolysin concentration, from Calculate Macrophage apoptosis.xlsx [[PMID: 16177320]]        
        probApo                            = Pstru.MaclifeN.^(1/Pstru.expos); %Assign probability to each step given the probability from [[PMID: 16177320]] Assume 60 minutes of exposition required    
        macKill2                           = zeros(Pstru.numneu0,1); %Keep death monocytes
        macKill2(Pstru.DeaNeu == 1)        = 1; %Count death neutrophils
        Pstru.MaclifeNT                    = Pstru.MaclifeNT.*exp(-(Pstru.alpha*macKill2 + Pstru.beta)); %Store probabilities of all neutrophils
        probApo2                           = Pstru.MaclifeNT.^(1/Pstru.expos); %Assign probability to each step given the probability from [[PMID: 16177320]] Assume 60 minutes of exposition required      
        probApo(macKill == 0)              = 1; %Define the empty neutrophils as 0
        probApo2(macKill2 == 0)            = 1; %Define the empty neutrophils as 0
        randApop                           = rand; %Random number for apoptosis
        Pstru.neuD                         = [Pstru.neuD;Pstru.neu(probApo < randApop,:)]; %Save position of death neutrophils
        Pstru.neu(probApo < randApop,:)    = []; %Remove neutrophils
        Pstru.triNeu(probApo < randApop,:) = []; %Remove neutrophils triangle locations
        Pstru.dist(:,probApo < randApop)   = []; %Remove distance to bacteria 
        Pstru.rcap1(:,probApo < randApop)  = []; %Repeat for all neutrophils
        Pstru.numneu                       = Pstru.numneu - sum(probApo < randApop); %Substract death neutrophils from the count
        Pstru.eatenN(probApo < randApop)   = []; %Remove the counter of eaten bacteria
        Pstru.neatN(probApo < randApop)    = []; %Remove intrinsic time
        Pstru.indNeu(probApo < randApop,:) = []; %Remove the IL1B matrix
        Pstru.MaclifeN(probApo < randApop) = []; %Remove the life of neutrophils
        Pstru.DeaNeu(probApo2 < randApop)  = 0; %Put zero on death neutrophils    
        Pstru.neuCount(probApo < randApop) = []; %Remove the inner clock of monocytes 
    end
    %% Neutrophils natural decay
    if numel(Pstru.neu) ~= 0
        Pstru.neuCount = Pstru.neuCount + 1;
        neuCicle = fix(Pstru.neuCount/Pstru.NeuHalf) == Pstru.neuCount/Pstru.NeuHalf; %Set the neutrophils that reach their half-life
        selDeat  = neuCicle.*fix(rand(length(neuCicle),1)*2); %Probability of 50% to die once the half-life is reached
        selDeat  = logical(selDeat); %Transform to logical
        if sum(selDeat) > 0
%             numDeat                 = round(Pstru.numneu/2); %Calculate the number of monocytes to die
%             selDeat                 = randsample(1:Pstru.numneu,numDeat); %Select the monocytes to die
            Pstru.neuD              = [Pstru.neuD;Pstru.neu(selDeat,:)]; %Save position of death neutrophils
            Pstru.neu(selDeat,:)    = []; %Remove monocytes
            Pstru.triNeu(selDeat,:) = []; %Remove monocytes triangle locations
            Pstru.dist(:,selDeat)   = []; %Remove distance to bacteria 
            Pstru.rcap1(:,selDeat)  = []; %Repeat for all monocytes
            Pstru.numneu            = Pstru.numneu - sum(selDeat); %Substract death monocytes from the count
            Pstru.eatenN(selDeat)   = []; %Remove the counter of eaten bacteria
            Pstru.neatN(selDeat)    = []; %Remove intrinsic time
            Pstru.indNeu(selDeat,:) = []; %Remove the IL1B matrix
            Pstru.MaclifeN(selDeat) = []; %Remove the life of monocytes
            Pstru.DeaNeu(selDeat)   = 0; %Put zero on death monocytes
            Pstru.neuCount(selDeat) = []; %Remove the inner clock of neutrophils
        end
    end 
    %% Bacterial movement through the mobile phase
    if Pstru.nb > 0
        [theta,phi,~]                                  = cart2sph(Pstru.pos(:,1),Pstru.pos(:,2),Pstru.pos(:,3)); %Transform to polar
        phi(Pstru.step > Pstru.step1)                  = phi(Pstru.step > Pstru.step1) + pi/12; %Move the bacteria thorugh the lining liquid
        [Pstru.pos(:,1),Pstru.pos(:,2),Pstru.pos(:,3)] = sph2cart(theta,phi,Pstru.AlvRad); %Fix the radious
        Pstru.pos(Pstru.step > Pstru.step1,:)          = Pstru.pos(Pstru.step > Pstru.step1,:) + Pstru.step3*Pstru.pos(Pstru.step > Pstru.step1,:); %Radial flow
    end
    %% Bacteria leave the alveolus
    if Pstru.nb > 0
        fuera               = phi > Pstru.exit; %Count the bacteria out of the alveolus
        Pstru.fuera         = Pstru.fuera + sum(fuera);
        Pstru.out           = Pstru.out + sum(fuera); %Count the spreaded bacteria
        Pstru.pos(fuera,:)  = []; %Remove bacteria
        Pstru.step(fuera)   = []; %Remove steps
        Pstru.div(fuera)    = []; %Remove cycles
        Pstru.probAB(fuera) = []; %Remove probability
        Pstru.nb            = Pstru.nb - sum(fuera); %Substract bacteria from the count
    end
    %% Bacteria die by antibiotics
    if Pstru.nb > 0
        if Pstru.n > (Pstru.antibHour*60)
            Pstru.nab    = Pstru.nab + 1; %Iterations after antibiotics
            currentProb  = (Pstru.probAB).^(1/(60*Pstru.FT)); %Probability of surviving in the current step
            currentProb  = (1 - currentProb)*Pstru.antibi; %Probability of dying in the current step
            currentProb  = (1 - currentProb); %Probability of surviving in the current step with antibiotics
            r            = rand(length(currentProb),1);
            killBac      = r > currentProb; %Bacteria killed by antibiotics   
            Pstru.antibi = Pstru.antibi*exp(-Pstru.antibiK*Pstru.nab); %Decay of antibiotics concentration
            if sum(killBac) ~= 0
                Pstru.pos(killBac,:)  = []; %Remove bacteria
                Pstru.step(killBac)   = []; %Remove steps
                Pstru.div(killBac)    = []; %Remove cycles
                Pstru.probAB(killBac) = []; %Remove probability
                Pstru.nb              = Pstru.nb - sum(killBac); %Substract bacteria from the count
            end
        end
    end
    %% Count the bacteria per epithelial cell
    if Pstru.nb > 0
        for ntri = 1:length(Pstru.TRI(:,1))
        Tra = squeeze(Pstru.Tra(:,:,ntri)); %Take the tranforming matrix
        Cen = Pstru.Cen(ntri,:); %Take the origin of coordinates axis
        BT  = zeros(length(Pstru.pos(:,1)),3); %Define the bacteria position vector in the new coordinates
        for nco = 1:3
            BT(:,nco) = (Pstru.pos(:,nco) - Cen(nco)); %Remove the origin of coordinates
        end
        BT                 = BT*Tra; %Transform the coordinates
        BTp                = sum(BT(:,1:2),2); %Sum the x and y coordinates
        Tv                 = [Pstru.x(Pstru.TRI(ntri,1)),Pstru.y(Pstru.TRI(ntri,1)),Pstru.z(Pstru.TRI(ntri,1))]; %Take one of the nodes to calculate the distance to bacteria
        Dtb                = sqrt((Pstru.pos(:,1) - Tv(1)).^2 + (Pstru.pos(:,2) - Tv(2)).^2 +(Pstru.pos(:,3) - Tv(3)).^2); %Calculate the distance of bacteria to the node
        Pstru.matBac(ntri) = sum(BT(:,1)>=0 & BT(:,2)>=0 & BTp <= 1 & Dtb<(Pstru.AlvRad/2)); %Count bacteria on top of the triangles
        end
    end
end
end
%% Function that defines the icosaedron
function [x,y,z,TRI,trio,Cen,Tra,Te] = defineIco(fre,fff,AlvRad)
[x,y,z,TRI] = make_icosahedron(fre,AlvRad,1,1,1,fff); %Take the icosaedron parameters from the make_icosahedron function
trio        = zeros(length(TRI(:,1)),3); %Define the variable of neighbour triangles
Cen         = zeros(length(TRI(:,1)),3); %Define the variable of originl of coordinates
Te          = zeros(length(TRI(:,1)),3); %Define the variable of triangle centroids
Tra         = zeros(3,3,length(TRI(:,1))); %Define the variable of transforming matrix
com         = [1,2;1,3;2,3]; %Define the indexes to generate the vectors for the new coordinates axis
for ntri = 1:length(TRI(:,1))
    for tri = 1:3
        pareja         = find(sum(TRI(ntri,com(tri,1)) == TRI,2) & sum(TRI(ntri,com(tri,2)) == TRI,2)); %Look for the neighbour triangles
        trio(ntri,tri) = pareja(pareja ~= ntri); %Take the triangles sharing an edge
    end
    M             = [transpose(x(TRI(ntri,:))),transpose(y(TRI(ntri,:))),transpose(z(TRI(ntri,:)))]; %Origin of coordinates
    N             = cross(M(2,:) - M(1,:),M(3,:) - M(1,:)); %Normal vector
    T             = [M(2,:) - M(1,:);M(3,:) - M(1,:);N - M(1,:)]; %Inverse of the transforming matrix
    Cen(ntri,:)   = M(1,:); %Origin of coordinates
    Tra(:,:,ntri) = T^-1; %Transforming matrix
    Tv            = [transpose(x(TRI(ntri,:))),transpose(y(TRI(ntri,:))),transpose(z(TRI(ntri,:)))]; %Calculate the centroids of the triangles
    Te(ntri,:)    = mean(Tv); %Centroids of the triangles
end
save('dataIco.mat','x','y','z','TRI','trio','Cen','Tra','Te') %Save the icosaedron parameters
end
%% Function that defines the cell movement
function [CellPos,TriCel,Pstru] = movement(CellPos,NumCel,TriCel,Pstru,isMonocyte)
%Locate phagocytes on top of the corresponding triangles
    if numel(CellPos) ~= 0 
        for ntri = 1:length(Pstru.TRI(:,1)) %Assign the triangle over which the phagocytes are
            Tra = squeeze(Pstru.Tra(:,:,ntri)); %Define the transformation matriz
            Cen = Pstru.Cen(ntri,:); %Define the centres of the new axis of coordinates
            BT  = zeros(length(CellPos(:,1)),3); %Define the position of phagocytes
            for nco = 1:3 %For the three dimensions
                BT(:,nco) = (CellPos(:,nco) - Cen(nco)); %Substract the zero of the axis
            end
            BT             = BT*Tra; %Transform the coordinates of bacteria
            BTp            = sum(BT(:,1:2),2); %Calculate the distance from the centre in Manhattan coordinates
            Tv             = [Pstru.x(Pstru.TRI(ntri,1)),Pstru.y(Pstru.TRI(ntri,1)),Pstru.z(Pstru.TRI(ntri,1))]; %Obtain the coordinates of one the the nodes of the triangles
            Dtb            = sqrt((CellPos(:,1) - Tv(1)).^2 + (CellPos(:,2) - Tv(2)).^2 +(CellPos(:,3) - Tv(3)).^2); %Calculate the distance of bacteria to this node 
            selMac         = (BT(:,1) >= 0 & BT(:,2) >= 0 & BTp <= 1 & Dtb < (Pstru.AlvRad/2)); %Define the criteria to be inside the triangle
            TriCel(selMac) = ntri; %Assign the triangle to the phagocyte
        end
        %Phagocytes move following closest bacteria
        Pstru.dist            = zeros(length(Pstru.pos(:,1)),NumCel); %Define the distance matrix between bacteria and phagocytes
        MacDist               = squareform(pdist(CellPos)); %Calculate distance between phagocytes 
        MacDist(MacDist == 0) = Pstru.macsiz*2 + 1; %Remove the zeros in the matrix
        CloseMacS             = min(MacDist,[],2) < Pstru.macsiz*2; %Find the phagocytes that approach eachother too much
        MacVec                = zeros(NumCel,3); %Define the vector to the closest bacterium
        for m = 1:NumCel
            Pstru.rcap2 = rand(size(Pstru.dist(:,1))); %Probability of not being eaten because of the protection of the capsule
            Pstru.rcap1 = []; %Define the probability of not being eaten for phagocytes
            for rere = 1:NumCel
                Pstru.rcap1 = [Pstru.rcap1,Pstru.rcap2]; %Repeat for all phagocytes
            end
            Pstru.dist(:,m)  = sqrt((CellPos(m,1) - Pstru.pos(:,1)).^2 + (CellPos(m,2) - Pstru.pos(:,2)).^2 + (CellPos(m,3) - Pstru.pos(:,3)).^2); %Measure distance to bacteria
            logic1     = ((min(Pstru.dist(:,m)) < Pstru.cel*Pstru.TrGra).*(Pstru.rcap2(min(Pstru.dist(:,m)) == Pstru.dist(:,m)) >= Pstru.capsule)); %Find the closest bacteria to phagocytes
            if numel(logic1) == 0
               logic1 = 0;
            end
            Pstru.mac0 = CellPos; %Save previous state
            feelNeu    = 0;
            Pstru.distN = zeros(length(Pstru.neuD(:,1)),NumCel); %Define the distance matrix between bacteria and phagocytes
            if (isMonocyte == 1 && numel(Pstru.neuD) > 0)
                Pstru.distN(:,m)  = sqrt((CellPos(m,1) - Pstru.neuD(:,1)).^2 + (CellPos(m,2) - Pstru.neuD(:,2)).^2 + (CellPos(m,3) - Pstru.neuD(:,3)).^2); %Measure distance to neutrophils
                feelNeu           = (min(Pstru.distN(:,m)) < Pstru.cel*Pstru.TrGra); %Find the closest bacteria to phagocytes
                if numel(feelNeu) == 0
                   feelNeu = 0;
                end
            end
            if feelNeu == 1
                for nco = 1:3 %For the three dimensions
                    MacVec(m,nco) = Pstru.neuD(min(Pstru.distN(:,m)) == Pstru.distN(:,m),nco) - CellPos(m,nco); %Calculate the vector to the closest bacterium 
                end
                for nco = 1:3 %For the three dimensions
                    MacVec(:,nco) = MacVec(:,nco)./sqrt(sum(MacVec.^2,2)); %Normalize the vector
                end
                CellPos(m,:)          = CellPos(m,:) + MacVec(m,:)*Pstru.stepm; %Move into the closest bacterium 
                MacDist               = squareform(pdist(CellPos)); %Calculate distance between phagocytes 
                MacDist(MacDist == 0) = Pstru.macsiz*2 + 1; %Remove the zeros in the matrix
                CloseMac              = min(MacDist,[],2) < Pstru.macsiz/2; %Find the macrophages that approach eachother too much
            else
                if (logic1 == 1 && numel(Pstru.pos) > 0)
                    for nco = 1:3 %For the three dimensions
                        MacVec(m,nco) = Pstru.pos(min(Pstru.dist(:,m)) == Pstru.dist(:,m),nco) - CellPos(m,nco); %Calculate the vector to the closest bacterium 
                    end
                    for nco = 1:3 %For the three dimensions
                        MacVec(:,nco) = MacVec(:,nco)./sqrt(sum(MacVec.^2,2)); %Normalize the vector
                    end
                    CellPos(m,:)          = CellPos(m,:) + MacVec(m,:)*Pstru.stepm; %Move into the closest bacterium 
                    MacDist               = squareform(pdist(CellPos)); %Calculate distance between phagocytes 
                    MacDist(MacDist == 0) = Pstru.macsiz*2 + 1; %Remove the zeros in the matrix
                    CloseMac              = min(MacDist,[],2) < Pstru.macsiz/2; %Find the macrophages that approach eachother too much
                else
                    d1                                       = rand*2 - 1; %For random angle
                    d2                                       = rand*2 - 1; %For random angle
                    [theta,phi,~]                            = cart2sph(CellPos(m,1),CellPos(m,2),CellPos(m,3)); %Transform to polar 
                    theta                                    = theta + rand*(d1./abs(d1)).*asin(Pstru.stepm/Pstru.AlvRad); %Random direction 1
                    phi                                      = phi + rand*(d2./abs(d2)).*asin(Pstru.stepm/Pstru.AlvRad); %Random direction 2
                    Pstru.mac0                               = CellPos; %Save previous state 
                    [CellPos(m,1),CellPos(m,2),CellPos(m,3)] = sph2cart(theta,phi,Pstru.AlvRad); %Transform to cartesian 
                    MacDist                                  = squareform(pdist(CellPos)); %Calculate distance between phagocytes 
                    MacDist(MacDist == 0)                    = Pstru.macsiz*2 + 1; %Remove the zeros in the matrix
                    CloseMac                                 = min(MacDist,[],2) < Pstru.macsiz/2; %Find the phagocytes that approach eachother too much
                end
            end
            if sum(CloseMac) ~= 0
                CellPos((CloseMac == 1 & CloseMacS == 0),:) = Pstru.mac0((CloseMac == 1 & CloseMacS == 0),:); %Prevent moving through another phagocyte 
            end
            [theta,phi,~]                            = cart2sph(CellPos(:,1),CellPos(:,2),CellPos(:,3)); %Transform to polar 
            [CellPos(:,1),CellPos(:,2),CellPos(:,3)] = sph2cart(theta,phi,Pstru.AlvRad); %Fix the radious 
        end
    end
end
%% Function that defines bacteria phagocytosis
function Pstru = phagocytosis(CellPos,NumCel,Eaten,nEaten,Pstru,isMonocyte)
    if Pstru.nb > 0
        if numel(CellPos) ~= 0
            Eaten                       = Eaten + sum((Pstru.dist < Pstru.macsiz).*(Pstru.rcap1 >= Pstru.capsule),1); %Count the attached bacteria per macrophages
            Pstru.baceat                = Pstru.baceat + sum(sum((Pstru.dist < Pstru.macsiz).*(Pstru.rcap1 >= Pstru.capsule),1)); %Count the eaten bacteria by monocytes
            Eaten(Eaten > Pstru.maxeat) = []; %Remove phagocytes with too many bacteria attached
            Eaten                       = Eaten.*exp(-Pstru.clebac.*nEaten); %Bacteria are phagocyted
            Eaten                       = round(Eaten); %Round number of bacteria attached
            if numel(Pstru.dist) > 0    
                Pstru.pos((min(Pstru.dist,[],2) < Pstru.macsiz).*(Pstru.rcap2 >= Pstru.capsule) == 1,:)  = []; %Remove bacteria attached to phagocytes
                Pstru.step((min(Pstru.dist,[],2) < Pstru.macsiz).*(Pstru.rcap2 >= Pstru.capsule) == 1)   = []; %Remove steps
                Pstru.div((min(Pstru.dist,[],2) < Pstru.macsiz).*(Pstru.rcap2 >= Pstru.capsule) == 1)    = []; %Remove cycles
                Pstru.probAB((min(Pstru.dist,[],2) < Pstru.macsiz).*(Pstru.rcap2 >= Pstru.capsule) == 1) = []; %Remove probabilities
            end
            if NumCel > 0
                Pstru.nb = Pstru.nb - sum((min(Pstru.dist,[],2) < Pstru.macsiz).*(Pstru.rcap2 >= Pstru.capsule) == 1); %Substract bacteria from the count
            end
            nEaten = nEaten + 1; %Count the intrinsic time
        end
    end
    if (numel(CellPos) ~= 0 && isMonocyte == 1)
        if numel(Pstru.distN) > 0    
            Pstru.neuD((min(Pstru.distN,[],2) < Pstru.macsiz),:)   = []; %Remove death neutrophil
            Pstru.infMon((min(Pstru.distN,[],1) < Pstru.macsiz),:) = 0; %Transform monocyte to antiinflammatory monocyte
            Pstru.intramon((min(Pstru.distN,[],1) < Pstru.macsiz)) = {zeros(sum((min(Pstru.distN,[],1) < Pstru.macsiz)),Pstru.Ndelay)}; %Replace initial condition by the anti-inflammatory monocytes
        end
    end
end
%% Epithelial cell model
function dfx = modeleqs(t,x,Pstru)
%Initial configuration
x(x < 1e-6) = 0; %Prevent the negative values
pars2       = Pstru.pars2; %Introduce the parameters into the structure
dx          = Pstru.cel/Pstru.N; %Thickness of each layer microm
%% Spatial model
spatial                  = zeros(1,Pstru.numEQS); %Define the spatial variable
dD                       = zeros(Pstru.numEQS,Pstru.N); %Define the gradient variable
spatial(Pstru.IndexSpat) = 1; %Call the spatial variables
for ivar = 1:Pstru.numEQS
    if spatial(ivar) == 1
        Di                   = Pstru.dif(ivar); %Take the diffusion constant
        FP                   = x((ivar - 1)*Pstru.N+1:ivar*Pstru.N); %Take the variable
        FP(Pstru.alvEnt)     = 0; %Entry of the alveolus
        dx1                  = Di*(sum(FP(Pstru.trio),2) - 3*FP)/dx; %Calculation of the gradients
        dD(ivar,:)           = dx1; %Save the gradient
    end
end
%% Initial conditions
IRAK1  = transpose(x(1:Pstru.N));
IRAK1p = transpose(x(1*Pstru.N+1:2*Pstru.N));
IKK    = transpose(x(2*Pstru.N+1:3*Pstru.N));
IKKa   = transpose(x(3*Pstru.N+1:4*Pstru.N));
NFkB   = transpose(x(4*Pstru.N+1:5*Pstru.N));
mIkBa  = transpose(x(5*Pstru.N+1:6*Pstru.N));
IkBa   = transpose(x(6*Pstru.N+1:7*Pstru.N));
mMCP1  = transpose(x(7*Pstru.N+1:8*Pstru.N));
MCP1   = transpose(x(8*Pstru.N+1:9*Pstru.N));
Pneumo = transpose(x(9*Pstru.N+1:10*Pstru.N));
IL8    = transpose(x(10*Pstru.N+1:11*Pstru.N));
Dam    = transpose(x(11*Pstru.N+1:12*Pstru.N));
mCXCL5 = transpose(x(12*Pstru.N+1:13*Pstru.N));
CXCL5  = transpose(x(13*Pstru.N+1:14*Pstru.N));
%% Model parameters
par = [0.095494006372294021     %01
       0.095494006372294021     %02
       0.00095092672985701396   %03
       3.148117756260155        %04
       6.6237841144233673       %05
       0.14969105208857217      %06
       0.14969105208857217      %07
       83.992067558019102       %08
       0.78238239329941495      %09
       0.011554688772929096     %10
       1.7167747622178087       %11
       540.25955106495292       %12
       1.5603360734858587       %13
       19.809822965869529       %14
       123.7572891589779        %15
       0.00070254758737242802   %16
       252.63310249152755       %17
       0.59996940751789452      %18
       0.074756548942597978     %19
       28.9                     %20 28.9 (value calculated for alveolus [Obtained from calPar.m and MCP1 clearance from lung.xlsx]) Valid for MCP1 and IL1B [[PMID: 14695119]]
       1                        %21
       1                        %22
       1                        %23
       1];                      %24     
%% Define parameters
par          = par(1:24).*pars2; %Modify the parameters
kirak1syn    = par(1);
kyrak1deg    = par(2);
kirak1ph1    = par(3);
kirak1ph2    = par(4);
kirak1pdeg   = par(5);
kikksyn      = par(6);
kikkdeg      = par(7);
kikkact      = par(8);
kikkadeg     = par(9);
knfkbgain    = par(10);
knfkbloss    = par(11);
kmikbatransc = par(12);
kmikbadeg    = par(13);
kikbatransl  = par(14);
kikbaloss    = par(15);
kmil8transc1 = par(16);
kmil8transc2 = par(17);
kmil8deg     = par(18);
kil8transl   = par(19); % The same for MCP-1 and IL1B [[PMID: 16834785]]
kil8deg      = par(20);
K1           = par(21);
K2           = par(22);
K3           = par(23);
Ntot         = par(24);
%% Input signals
antigens = Pstru.antigens; %Antigens per bacterium presented to epithelial cells
irakMac  = IRAK1*0; %Define the input for IL1B
if Pstru.nummac > 0
    for nm = 1:length(Pstru.eaten)
        irakMac(Pstru.indMac(nm,1),Pstru.indMac(nm,2)) = Pstru.eaten(nm); %Create the input for IL1B production based on the macrophages location
    end
end
if (t >= (Pstru.pneumotime1 - Pstru.pneumotime2) && t < Pstru.pneumotime1)
    pneumoRate = Pstru.pneumo1 - (t - (Pstru.pneumotime1 - Pstru.pneumotime2))*((Pstru.pneumo1 - Pstru.pneumo2)/5); %Pneumolysin production rate between 10 and 15 hours
elseif t >= Pstru.pneumotime1
    pneumoRate = Pstru.pneumo2; %Pneumolysin production rate after 15 hours
else
    pneumoRate = Pstru.pneumo1; %Pneumolysin production rate before 10 hours
end
%% Differential equations
dxX1  = dD(1,:) + kirak1syn - kyrak1deg.*IRAK1 - kirak1ph1.*IRAK1.*Pstru.matBac*antigens; %IRAK1 
dxX2  = dD(2,:) + kirak1ph1.*IRAK1.*Pstru.matBac*antigens - kirak1pdeg.*IRAK1p; %IRAK1p
dxX3  = dD(3,:) + kikksyn - kikkact.*IKK.*IRAK1p - kikkdeg.*IKK; %IKK
dxX4  = dD(4,:) + kikkact.*IKK.*IRAK1p - kikkadeg.*IKKa; %IKKa
dxX5  = dD(5,:) + knfkbgain.*IKKa.*((Ntot - NFkB)./(K1 + IkBa + IKKa)) - knfkbloss.*((IkBa.*NFkB)./(K2 + NFkB)); %NFkB
dxX6  = dD(6,:) + kmikbatransc.*NFkB - kmikbadeg.*mIkBa; %mIkBa
dxX7  = dD(7,:) + kikbatransl.*mIkBa - kikbaloss.*IKKa.*IkBa.*((Ntot - NFkB)./(K3 + IkBa + IKKa));%IkBa
dxX8  = dD(8,:) + kmil8transc1 + kmil8transc2.*NFkB - kmil8deg.*mMCP1; %MCP-1m
dxX9  = dD(9,:) + Pstru.FN*kil8transl.*mMCP1 - kil8deg.*MCP1; %MCP-1
dxX10 = dD(10,:) + pneumoRate*Pstru.matBac - kil8deg.*Pneumo; %Pneumolysin (fit decay rate)
dxX11 = dD(11,:) + kil8transl*transpose(Pstru.IL8m) - kil8deg.*IL8; %IL8
dxX12 = dD(12,:) + transpose(Pstru.BarDam).*(Pstru.maxDam - transpose(Pstru.BarDam)); %Barrier damage
dxX13 = dD(13,:) + kmil8transc1 + kmil8transc2.*NFkB - kmil8deg.*mCXCL5; %CXCL5m
dxX14 = dD(14,:) + Pstru.FN*kil8transl.*mCXCL5 - kil8deg.*CXCL5; %CXCL5
dfx   = [dxX1(:);dxX2(:);dxX3(:);dxX4(:);dxX5(:);dxX6(:);dxX7(:);dxX8(:);dxX9(:);dxX10(:);dxX11(:);dxX12(:);dxX13(:);dxX14(:)]; %Merge equations
end
%% Function of intracellular network of phagocytes
function dfx = celleqs(~,x,Pstru,BacCell)
%Initial configuration
x(x < 1e-6) = 0; %Prevent the negative values
pars2       = Pstru.pars2; %Introduce the parameters into the structure
%% Initial conditions
IRAK1  = x(1);
IRAK1p = x(2);
IKK    = x(3);
IKKa   = x(4);
NFkB   = x(5);
mIkBa  = x(6);
IkBa   = x(7);
mMCP1  = x(8);
MCP1   = x(9);
%% Model parameters
par = [0.095494006372294021     %01
       0.095494006372294021     %02
       0.00095092672985701396   %03
       3.148117756260155        %04
       6.6237841144233673       %05
       0.14969105208857217      %06
       0.14969105208857217      %07
       83.992067558019102       %08
       0.78238239329941495      %09
       0.011554688772929096     %10
       1.7167747622178087       %11
       540.25955106495292       %12
       1.5603360734858587       %13
       19.809822965869529       %14
       123.7572891589779        %15
       0.00070254758737242802   %16
       252.63310249152755       %17
       0.59996940751789452      %18
       0.074756548942597978     %19
       28.9                     %20 28.9 (value calculated for alveolus [Obtained from calPar.m and MCP1 clearance from lung.xlsx]) Valid for MCP1 and IL1B [[PMID: 14695119]]
       1                        %21
       1                        %22
       1                        %23
       1];                      %24     
%% Define parameters
par          = par(1:24).*pars2; %Modify the parameters
kirak1syn    = par(1);
kyrak1deg    = par(2);
kirak1ph1    = par(3);
kirak1ph2    = par(4);
kirak1pdeg   = par(5);
kikksyn      = par(6);
kikkdeg      = par(7);
kikkact      = par(8);
kikkadeg     = par(9);
knfkbgain    = par(10);
knfkbloss    = par(11);
kmikbatransc = par(12);
kmikbadeg    = par(13);
kikbatransl  = par(14);
kikbaloss    = par(15);
kmil8transc1 = par(16);
kmil8transc2 = par(17);
kmil8deg     = par(18);
kil8transl   = par(19); % The same for MCP-1 and IL1B [[PMID: 16834785]]
kil8deg      = par(20);
K1           = par(21);
K2           = par(22);
K3           = par(23);
Ntot         = par(24);
%% Input signals
antigens = Pstru.antigens; %Antigens per bacterium presented to epithelial cells
%% Differential equations
dxX1  = kirak1syn - kyrak1deg.*IRAK1 - kirak1ph1.*IRAK1.*BacCell*antigens; %IRAK1 
dxX2  = kirak1ph1.*IRAK1.*BacCell*antigens - kirak1pdeg.*IRAK1p; %IRAK1p
dxX3  = kikksyn - kikkact.*IKK.*IRAK1p - kikkdeg.*IKK; %IKK
dxX4  = kikkact.*IKK.*IRAK1p - kikkadeg.*IKKa; %IKKa
dxX5  = knfkbgain.*IKKa.*((Ntot - NFkB)./(K1 + IkBa + IKKa)) - knfkbloss.*((IkBa.*NFkB)./(K2 + NFkB)); %NFkB
dxX6  = kmikbatransc.*NFkB - kmikbadeg.*mIkBa; %mIkBa
dxX7  = kikbatransl.*mIkBa - kikbaloss.*IKKa.*IkBa.*((Ntot - NFkB)./(K3 + IkBa + IKKa));%IkBa
dxX8  = kmil8transc1 + kmil8transc2.*NFkB - kmil8deg.*mMCP1; %MCP-1m
dxX9  = Pstru.FN*kil8transl.*mMCP1 - kil8deg.*MCP1; %MCP-1
dfx   = [dxX1;dxX2;dxX3;dxX4;dxX5;dxX6;dxX7;dxX8;dxX9]; %Merge equations
end
%% Function for barrier damage spread from neutrophils
function dfx = barrDamage(~,x,Pstru,isProinf)
%Initial configuration
x(x < 1e-6) = 0; %Prevent the negative values
%Parameters
k1      = Pstru.barrDam;
k2      = Pstru.barrRec;
%Differential equation
dfx(1) = k1 - k2*x(1);
end
