#GENERATE DATA TO PLOT FIGURES############################################################################# ----

library(ggplot2)
library(readr)
library(reshape2)
library(lattice)
library(viridisLite)
source('multiplot.R')

WD1 <- getwd()
WD2<-paste(WD1,"/CSV_data_nominal",sep="")
WD3<-paste(WD1,"/CSV_data_all",sep="")
setwd(WD2)

TotalDataPneu <- read_csv("TotalDataPneu.csv", col_names = FALSE)
nombres<-c('T','BacSim','MacSim','MonSim','NeuSim','DamSim','OutSim','il8Sim','McpSim','pneSim','CxcSim')
for(indice1 in 2:11){
  datos0<-data.frame()
  for(indice2 in 0:1){
    leer<-paste(nombres[indice1],'_',as.character(indice2),'.csv',sep='')
    datos1<-read.csv(leer, header=FALSE)
    datos1$time<-seq(from=1/6,to=24,by=1/6)
    datos1$aged<-rep(indice2,144)
    datos0<-rbind(datos0,datos1)
  }
  assign(nombres[indice1], datos0)
}
#Melt data from raw data
mBac<-melt(data = BacSim, id.vars = c("time", "aged"))
mMac<-melt(data = MacSim, id.vars = c("time", "aged"))
mMon<-melt(data = MonSim, id.vars = c("time", "aged"))
mNeu<-melt(data = NeuSim, id.vars = c("time", "aged"))
mDam<-melt(data = DamSim, id.vars = c("time", "aged"))
mOut<-melt(data = OutSim, id.vars = c("time", "aged"))
mil8<-melt(data = il8Sim, id.vars = c("time", "aged"))
mMcp<-melt(data = McpSim, id.vars = c("time", "aged"))
mpne<-melt(data = pneSim, id.vars = c("time", "aged"))
mcxcl5<-melt(data = CxcSim, id.vars = c("time", "aged"))
#Generate plots for no aged solutions
mBac0<-mBac[with(mBac,aged==0),c(1,3:4)]
mMac0<-mMac[with(mMac,aged==0),c(1,3:4)]
mMon0<-mMon[with(mMon,aged==0),c(1,3:4)]
mNeu0<-mNeu[with(mNeu,aged==0),c(1,3:4)]
mDam0<-mDam[with(mDam,aged==0),c(1,3:4)]
mOut0<-mOut[with(mOut,aged==0),c(1,3:4)]
mil80<-mil8[with(mil8,aged==0),c(1,3:4)]
mMcp0<-mMcp[with(mMcp,aged==0),c(1,3:4)]
mpne0<-mpne[with(mpne,aged==0),c(1,3:4)]
mcxcl50<-mcxcl5[with(mcxcl5,aged==0),c(1,3:4)]
#Generate plots for aged solutions
mBac1<-mBac[with(mBac,aged==1),c(1,3:4)]
mMac1<-mMac[with(mMac,aged==1),c(1,3:4)]
mMon1<-mMon[with(mMon,aged==1),c(1,3:4)]
mNeu1<-mNeu[with(mNeu,aged==1),c(1,3:4)]
mDam1<-mDam[with(mDam,aged==1),c(1,3:4)]
mOut1<-mOut[with(mOut,aged==1),c(1,3:4)]
mil81<-mil8[with(mil8,aged==1),c(1,3:4)]
mMcp1<-mMcp[with(mMcp,aged==1),c(1,3:4)]
mpne1<-mpne[with(mpne,aged==1),c(1,3:4)]
mcxcl51<-mcxcl5[with(mcxcl5,aged==1),c(1,3:4)]
#Data to plot no aged figures
FS <- 14
LS1 <- 0.5
LS2 <- 1
p10 <- ggplot(mBac0,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Bacteria") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p20 <- ggplot(mMac0,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Macrophages") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p30 <- ggplot(mMon0,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Monocytes") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p40 <- ggplot(mNeu0,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Neutrophils") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p50 <- ggplot(mDam0,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Damage") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p60 <- ggplot(mOut0,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Excreted bacteria") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p70 <- ggplot(mil80,aes(time,value,color=variable)) + geom_line(size=LS1) + ggtitle("IL-8") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p80 <- ggplot(mMcp0,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("MCP-1") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p90 <- ggplot(mpne0,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Pneumolysin") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p100 <- ggplot(mcxcl50,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("CXCL5") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p10D <- p10 + geom_point(data = TotalDataPneu, mapping = aes(x = X1, y = X2), inherit.aes = FALSE)
p20D <- p20 + geom_point(data = TotalDataPneu, mapping = aes(x = X1, y = X6), inherit.aes = FALSE)
p30D <- p30 + geom_point(data = TotalDataPneu, mapping = aes(x = X1, y = X5), inherit.aes = FALSE)
p40D <- p40 + geom_point(data = TotalDataPneu, mapping = aes(x = X1, y = X4), inherit.aes = FALSE)
#Data to plot  aged figures
FS <- 14
p11 <- ggplot(mBac1,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Bacteria") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p21 <- ggplot(mMac1,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Macrophages") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p31 <- ggplot(mMon1,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Monocytes") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p41 <- ggplot(mNeu1,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Neutrophils") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p51 <- ggplot(mDam1,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Damage") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p61 <- ggplot(mOut1,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Excreted bacteria") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p71 <- ggplot(mil81,aes(time,value,color=variable)) + geom_line(size=LS1) + ggtitle("IL-8") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p81 <- ggplot(mMcp1,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("MCP-1") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p91 <- ggplot(mpne1,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Pneumolysin") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
p101 <- ggplot(mcxcl51,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("CXCL5") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
setwd(WD3)
p10s <- vector("list", length = 6)
p20s <- vector("list", length = 6)
p30s <- vector("list", length = 6)
p40s <- vector("list", length = 6)
p50s <- vector("list", length = 6)
p60s <- vector("list", length = 6)
p70s <- vector("list", length = 6)
p80s <- vector("list", length = 6)
p90s <- vector("list", length = 6)
p100s <- vector("list", length = 6)
solInd <- c(66,64,72,70,62,68)
for(ind in 1:6){
  SolSelected <- solInd[ind]
  nombres<-c('T','BacSim','MacSim','MonSim','NeuSim','DamSim','OutSim','CXCSim','pneSim','McpSim','il8Sim')
  for(indice1 in 2:11){
    leer<-paste(nombres[indice1],'_',1,'.csv',sep='')
    datos0 <- read.csv(leer, header=FALSE)
    datos0$time <- seq(from=1/6,to=24,by=1/6)
    datos0$sol <- rep(1,144)
    
    for(indice2 in 2:96){
      leer<-paste(nombres[indice1],'_',as.character(indice2),'.csv',sep='')
      datos1 <- read.csv(leer, header=FALSE)
      datos1$time <- seq(from=1/6,to=24,by=1/6)
      datos1$sol <- rep(indice2,144)
      datos0 <- rbind(datos0,datos1)
    }
    assign(nombres[indice1], datos0)
  }
  
  if(SolSelected != 0){
    BacSim <- BacSim[BacSim$sol==SolSelected,]
    DamSim <- DamSim[DamSim$sol==SolSelected,]
    MacSim <- MacSim[MacSim$sol==SolSelected,]
    MonSim <- MonSim[MonSim$sol==SolSelected,]
    NeuSim <- NeuSim[NeuSim$sol==SolSelected,]
    OutSim <- OutSim[OutSim$sol==SolSelected,]
    CXCSim <- CXCSim[CXCSim$sol==SolSelected,]
    pneSim <- pneSim[pneSim$sol==SolSelected,]
    McpSim <- McpSim[McpSim$sol==SolSelected,]
    il8Sim <- il8Sim[il8Sim$sol==SolSelected,]
  }
  mBac<-melt(data = BacSim[,1:11], id.vars = c("time"))
  mMac<-melt(data = MacSim[,1:11], id.vars = c("time"))
  mMon<-melt(data = MonSim[,1:11], id.vars = c("time"))
  mNeu<-melt(data = NeuSim[,1:11], id.vars = c("time"))
  mDam<-melt(data = DamSim[,1:11], id.vars = c("time"))
  mOut<-melt(data = OutSim[,1:11], id.vars = c("time"))
  
  mil8<-melt(data = il8Sim[,1:11], id.vars = c("time"))
  mMcp<-melt(data = McpSim[,1:11], id.vars = c("time"))
  mpne<-melt(data = pneSim[,1:11], id.vars = c("time"))
  mcxcl5<-melt(data = CXCSim[,1:11], id.vars = c("time"))
  ##
  #data to plot selected solution by SolSelected.
  FS <- 14
  p10s[[ind]] <- ggplot(mBac,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Bacteria") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
  p20s[[ind]] <- ggplot(mMac,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Macrophages") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
  p30s[[ind]] <- ggplot(mMon,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Monocytes") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
  p40s[[ind]] <- ggplot(mNeu,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Neutrophils") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
  p50s[[ind]] <- ggplot(mDam,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Damage") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
  p60s[[ind]] <- ggplot(mOut,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Excreted bacteria") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
  p70s[[ind]] <- ggplot(mil8,aes(time,value,color=variable)) + geom_line(size=LS1) + ggtitle("IL-8") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
  p80s[[ind]] <- ggplot(mMcp,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("MCP-1") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
  p90s[[ind]] <- ggplot(mpne,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("Pneumolysin") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
  p100s[[ind]] <- ggplot(mcxcl5,aes(time,value,color=variable)) + geom_line(size=LS2) + ggtitle("CXCL5") + xlab("Time (hours)") + ylab("Amount (norm.)") + theme(legend.position = "none") + theme(axis.text.y = element_text(size = FS), axis.title.y = element_text(size = FS)) + theme(axis.text.x = element_text(size = FS), axis.title.x = element_text(size = FS))
}
setwd(WD1)
R0<-c()
Di<-c()
In<-c()
###
WD1 <- getwd()
WD2<-paste(WD1,"/CSV_data_all",sep="")
setwd(WD2)
nombres<-c('T','BacSim','MacSim','MonSim','NeuSim','DamSim','OutSim')
for(indice1 in 2:7){
  #eer<-paste('~/Rdir/alveolar_model_data/',nombres[indice1],'_',1,'.csv',sep='')
  leer<-paste(nombres[indice1],'_',1,'.csv',sep='')
  datos0 <- read.csv(leer, header=FALSE)
  datos0$time <- seq(from=1/6,to=24,by=1/6)
  datos0$sol <- rep(1,144)
  
  for(indice2 in 2:96){
    leer<-paste(nombres[indice1],'_',as.character(indice2),'.csv',sep='')
    #leer<-paste('~/Rdir/alveolar_model_data/',nombres[indice1],'_',as.character(indice2),'.csv',sep='')
    datos1 <- read.csv(leer, header=FALSE)
    datos1$time <- seq(from=1/6,to=24,by=1/6)
    datos1$sol <- rep(indice2,144)
    datos0 <- rbind(datos0,datos1)
  }
  assign(nombres[indice1], datos0)
}
BacSim$Media<-rowSums(BacSim[,1:10],na.rm = T)/10
DamSim$Media<-rowSums(DamSim[,1:10],na.rm = T)/10
MacSim$Media<-rowSums(MacSim[,1:10],na.rm = T)/10
MonSim$Media<-rowSums(MonSim[,1:10],na.rm = T)/10
NeuSim$Media<-rowSums(NeuSim[,1:10],na.rm = T)/10
OutSim$Media<-rowSums(OutSim[,1:10],na.rm = T)/10
BacSimM <- BacSim
setwd(WD1)
###
for(solution in 1:96){
  numerador <- sum(subset(BacSim,(sol==solution))[,13])*(24/144)
  denominador <- subset(BacSim,(sol==solution))[1,13]*24
  R0[solution] <- numerador/denominador
  Di[solution] <- sum(diff(subset(BacSim,(sol==solution))[,13]))
  In[solution] <- (subset(BacSim,(sol==solution))[length(subset(BacSim,(sol==solution))[,13]),13]-subset(BacSim,(sol==solution))[1,13])/subset(BacSim,(sol==solution))[1,13]
}
#R0
R0M <- matrix(R0, nrow = 12, byrow = FALSE)
R0A0 <- R0M[7:12,]
R0A1 <- R0M[1:6,]
rownames(R0A0)<-c(0,4,8,12,16,20)
colnames(R0A0)<-c(11,31,51,71,91,111,131,151)
rownames(R0A1)<-c(0,4,8,12,16,20)
colnames(R0A1)<-c(11,31,51,71,91,111,131,151)
#Difference
DiM <- matrix(Di, nrow = 12, byrow = FALSE)
DiA0 <- DiM[7:12,]
DiA1 <- DiM[1:6,]
rownames(DiA0)<-c(0,4,8,12,16,20)
colnames(DiA0)<-c(11,31,51,71,91,111,131,151)
rownames(DiA1)<-c(0,4,8,12,16,20)
colnames(DiA1)<-c(11,31,51,71,91,111,131,151)
#Increment
InM <- matrix(In, nrow = 12, byrow = FALSE)
InA0 <- InM[7:12,]
InA1 <- InM[1:6,]
rownames(InA0)<-c(0,4,8,12,16,20)
colnames(InA0)<-c(11,31,51,71,91,111,131,151)
rownames(InA1)<-c(0,4,8,12,16,20)
colnames(InA1)<-c(11,31,51,71,91,111,131,151)
#
R0A0L <- R0A0>1
R0A1L <- R0A1>1
Delay0 <- R0A1L
Delay4 <- rbind(matrix(rep(FALSE,8*1),nrow=1,byrow = TRUE),R0A1L[1:(6-1),])
Delay8 <- rbind(matrix(rep(FALSE,8*2),nrow=2,byrow = TRUE),R0A1L[1:(6-2),])
Delay12 <- rbind(matrix(rep(FALSE,8*3),nrow=3,byrow = TRUE),R0A1L[1:(6-3),])
Delay16 <- rbind(matrix(rep(FALSE,8*4),nrow=4,byrow = TRUE),R0A1L[1:(6-4),])
Delay20 <- rbind(matrix(rep(FALSE,8*5),nrow=5,byrow = TRUE),R0A1L[1:(6-5),])
Dif <- c()
Dif[1] <- sum(sum(abs(Delay0-R0A0L)))
Dif[2] <- sum(sum(abs(Delay4-R0A0L)))
Dif[3] <- sum(sum(abs(Delay8-R0A0L)))
Dif[4] <- sum(sum(abs(Delay12-R0A0L)))
Dif[5] <- sum(sum(abs(Delay16-R0A0L)))
Dif[6] <- sum(sum(abs(Delay20-R0A0L)))
names(Dif) <- c(0,4,8,12,16,20)
Message <-paste("The optimal delay in time for aged mice is between",names(Dif[Dif==min(Dif)])[1],"and",names(Dif[Dif==min(Dif)])[2],"hours.",sep=" ")
print(Message)


##################PLOT FIGURES############################################################################# ----

#Figure 2A, figure 3DL and figure 3UL
multiplot(p10, p20, p30, p40, cols = 2)
#Figure 2B
multiplot(p70, p80, p90, p100, cols = 2)
#Figure 2C
multiplot(p11, p21, p31, p41, cols = 2)
#Figure 2D
multiplot(p71, p81, p91, p101, cols = 2)
#Figure S1_4
multiplot(p70s[[1]], p80s[[1]], p90s[[1]], p100s[[1]], cols = 2)
#Figure S1_3
multiplot(p70s[[2]], p80s[[2]], p90s[[2]], p100s[[2]], cols = 2)
#Figure S1_2
multiplot(p70s[[3]], p80s[[3]], p90s[[3]], p100s[[3]], cols = 2)
#Figure S1_1
multiplot(p70s[[4]], p80s[[4]], p90s[[4]], p100s[[4]], cols = 2)
#Figure 3, top left panel
levelplot(R0A0,ylab = "Initial bacteria",xlab="Antibiotic delay (hours)", axes=FALSE, main="Young mice",at=seq(0, 15),col.regions = viridis(100))
#Figure 3, bottom left panel
levelplot(R0A1,ylab = "Initial bacteria",xlab="Antibiotic delay (hours)", axes=FALSE, main="Aged mice",at=seq(0, 15),col.regions = viridis(100))
#Figure 3, top center panel
levelplot(DiA0,ylab = "Initial bacteria",xlab="Antibiotic delay (hours)", axes=FALSE, main="Young mice",at=seq(-200, 4500, 100),col.regions = viridis(100))
#Figure 3, bottom center panel
levelplot(DiA1,ylab = "Initial bacteria",xlab="Antibiotic delay (hours)", axes=FALSE, main="Aged mice",at=seq(-200, 4500, 100),col.regions = viridis(100))
#Figure 3, top rigth panel
levelplot(InA0,ylab = "Initial bacteria",xlab="Antibiotic delay (hours)", axes=FALSE, main="Young mice",at=seq(-2, 35),col.regions = viridis(100))
#Figure 3, bottom rigth panel
levelplot(InA1,ylab = "Initial bacteria",xlab="Antibiotic delay (hours)", axes=FALSE, main="Aged mice",at=seq(-2, 35),col.regions = viridis(100))
#Figure 4TL
multiplot(p10s[[6]], p20s[[6]], p30s[[6]], p40s[[6]], cols = 2)
#Figure 4UM
multiplot(p10s[[4]], p20s[[4]], p30s[[4]], p40s[[4]], cols = 2)
#Figure 4UR
multiplot(p10s[[3]], p20s[[3]], p30s[[3]], p40s[[3]], cols = 2)
#Figure 4DL
multiplot(p10s[[5]], p20s[[5]], p30s[[5]], p40s[[5]], cols = 2)
#Figure 4DM
multiplot(p10s[[2]], p20s[[2]], p30s[[2]], p40s[[2]], cols = 2)
#Figure 4DR
multiplot(p10s[[1]], p20s[[1]], p30s[[1]], p40s[[1]], cols = 2)
#Figure S2
multiplot(p10D, p20D, p30D, p40D, cols = 2)
